// SPDX-License-Identifier: MIT
/*
 * Copyright (c) 2021-2023 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#include "t234_mss_channel.h"

#include <tegra_hwpm.h>
#include <hal/t234/t234_regops_allowlist.h>
#include <hal/t234/hw/t234_addr_map_soc_hwpm.h>
#include <hal/t234/t234_perfmon_device_index.h>

static struct hwpm_ip_aperture t234_mss_channel_inst0_perfmon_element_static_array[
	T234_HWPM_IP_MSS_CHANNEL_NUM_PERFMON_PER_INST] = {
	{
		.element_type = HWPM_ELEMENT_PERFMON,
		.element_index_mask = BIT(0),
		.element_index = 1U,
		.dt_mmio = NULL,
		.name = "perfmon_msschannel_parta0",
		.device_index = T234_MSS_CHANNEL_PARTA0_PERFMON_DEVICE_NODE_INDEX,
		.start_abs_pa = addr_map_rpg_pm_mss0_base_r(),
		.end_abs_pa = addr_map_rpg_pm_mss0_limit_r(),
		.start_pa = addr_map_rpg_pm_mss0_base_r(),
		.end_pa = addr_map_rpg_pm_mss0_limit_r(),
		.base_pa = addr_map_rpg_pm_base_r(),
		.alist = t234_perfmon_alist,
		.alist_size = ARRAY_SIZE(t234_perfmon_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = HWPM_ELEMENT_PERFMON,
		.element_index_mask = BIT(1),
		.element_index = 2U,
		.dt_mmio = NULL,
		.name = "perfmon_msschannel_parta1",
		.device_index = T234_MSS_CHANNEL_PARTA1_PERFMON_DEVICE_NODE_INDEX,
		.start_abs_pa = addr_map_rpg_pm_mss1_base_r(),
		.end_abs_pa = addr_map_rpg_pm_mss1_limit_r(),
		.start_pa = addr_map_rpg_pm_mss1_base_r(),
		.end_pa = addr_map_rpg_pm_mss1_limit_r(),
		.base_pa = addr_map_rpg_pm_base_r(),
		.alist = t234_perfmon_alist,
		.alist_size = ARRAY_SIZE(t234_perfmon_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = HWPM_ELEMENT_PERFMON,
		.element_index_mask = BIT(2),
		.element_index = 3U,
		.dt_mmio = NULL,
		.name = "perfmon_msschannel_parta2",
		.device_index = T234_MSS_CHANNEL_PARTA2_PERFMON_DEVICE_NODE_INDEX,
		.start_abs_pa = addr_map_rpg_pm_mss2_base_r(),
		.end_abs_pa = addr_map_rpg_pm_mss2_limit_r(),
		.start_pa = addr_map_rpg_pm_mss2_base_r(),
		.end_pa = addr_map_rpg_pm_mss2_limit_r(),
		.base_pa = addr_map_rpg_pm_base_r(),
		.alist = t234_perfmon_alist,
		.alist_size = ARRAY_SIZE(t234_perfmon_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = HWPM_ELEMENT_PERFMON,
		.element_index_mask = BIT(3),
		.element_index = 4U,
		.dt_mmio = NULL,
		.name = "perfmon_msschannel_parta3",
		.device_index = T234_MSS_CHANNEL_PARTA3_PERFMON_DEVICE_NODE_INDEX,
		.start_abs_pa = addr_map_rpg_pm_mss3_base_r(),
		.end_abs_pa = addr_map_rpg_pm_mss3_limit_r(),
		.start_pa = addr_map_rpg_pm_mss3_base_r(),
		.end_pa = addr_map_rpg_pm_mss3_limit_r(),
		.base_pa = addr_map_rpg_pm_base_r(),
		.alist = t234_perfmon_alist,
		.alist_size = ARRAY_SIZE(t234_perfmon_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = HWPM_ELEMENT_PERFMON,
		.element_index_mask = BIT(4),
		.element_index = 5U,
		.dt_mmio = NULL,
		.name = "perfmon_msschannel_partb0",
		.device_index = T234_MSS_CHANNEL_PARTB0_PERFMON_DEVICE_NODE_INDEX,
		.start_abs_pa = addr_map_rpg_pm_mss4_base_r(),
		.end_abs_pa = addr_map_rpg_pm_mss4_limit_r(),
		.start_pa = addr_map_rpg_pm_mss4_base_r(),
		.end_pa = addr_map_rpg_pm_mss4_limit_r(),
		.base_pa = addr_map_rpg_pm_base_r(),
		.alist = t234_perfmon_alist,
		.alist_size = ARRAY_SIZE(t234_perfmon_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = HWPM_ELEMENT_PERFMON,
		.element_index_mask = BIT(5),
		.element_index = 6U,
		.dt_mmio = NULL,
		.name = "perfmon_msschannel_partb1",
		.device_index = T234_MSS_CHANNEL_PARTB1_PERFMON_DEVICE_NODE_INDEX,
		.start_abs_pa = addr_map_rpg_pm_mss5_base_r(),
		.end_abs_pa = addr_map_rpg_pm_mss5_limit_r(),
		.start_pa = addr_map_rpg_pm_mss5_base_r(),
		.end_pa = addr_map_rpg_pm_mss5_limit_r(),
		.base_pa = addr_map_rpg_pm_base_r(),
		.alist = t234_perfmon_alist,
		.alist_size = ARRAY_SIZE(t234_perfmon_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = HWPM_ELEMENT_PERFMON,
		.element_index_mask = BIT(6),
		.element_index = 7U,
		.dt_mmio = NULL,
		.name = "perfmon_msschannel_partb2",
		.device_index = T234_MSS_CHANNEL_PARTB2_PERFMON_DEVICE_NODE_INDEX,
		.start_abs_pa = addr_map_rpg_pm_mss6_base_r(),
		.end_abs_pa = addr_map_rpg_pm_mss6_limit_r(),
		.start_pa = addr_map_rpg_pm_mss6_base_r(),
		.end_pa = addr_map_rpg_pm_mss6_limit_r(),
		.base_pa = addr_map_rpg_pm_base_r(),
		.alist = t234_perfmon_alist,
		.alist_size = ARRAY_SIZE(t234_perfmon_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = HWPM_ELEMENT_PERFMON,
		.element_index_mask = BIT(7),
		.element_index = 8U,
		.dt_mmio = NULL,
		.name = "perfmon_msschannel_partb3",
		.device_index = T234_MSS_CHANNEL_PARTB3_PERFMON_DEVICE_NODE_INDEX,
		.start_abs_pa = addr_map_rpg_pm_mss7_base_r(),
		.end_abs_pa = addr_map_rpg_pm_mss7_limit_r(),
		.start_pa = addr_map_rpg_pm_mss7_base_r(),
		.end_pa = addr_map_rpg_pm_mss7_limit_r(),
		.base_pa = addr_map_rpg_pm_base_r(),
		.alist = t234_perfmon_alist,
		.alist_size = ARRAY_SIZE(t234_perfmon_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = HWPM_ELEMENT_PERFMON,
		.element_index_mask = BIT(8),
		.element_index = 9U,
		.dt_mmio = NULL,
		.name = "perfmon_msschannel_partc0",
		.device_index = T234_MSS_CHANNEL_PARTC0_PERFMON_DEVICE_NODE_INDEX,
		.start_abs_pa = addr_map_rpg_pm_mss8_base_r(),
		.end_abs_pa = addr_map_rpg_pm_mss8_limit_r(),
		.start_pa = addr_map_rpg_pm_mss8_base_r(),
		.end_pa = addr_map_rpg_pm_mss8_limit_r(),
		.base_pa = addr_map_rpg_pm_base_r(),
		.alist = t234_perfmon_alist,
		.alist_size = ARRAY_SIZE(t234_perfmon_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = HWPM_ELEMENT_PERFMON,
		.element_index_mask = BIT(9),
		.element_index = 10U,
		.dt_mmio = NULL,
		.name = "perfmon_msschannel_partc1",
		.device_index = T234_MSS_CHANNEL_PARTC1_PERFMON_DEVICE_NODE_INDEX,
		.start_abs_pa = addr_map_rpg_pm_mss9_base_r(),
		.end_abs_pa = addr_map_rpg_pm_mss9_limit_r(),
		.start_pa = addr_map_rpg_pm_mss9_base_r(),
		.end_pa = addr_map_rpg_pm_mss9_limit_r(),
		.base_pa = addr_map_rpg_pm_base_r(),
		.alist = t234_perfmon_alist,
		.alist_size = ARRAY_SIZE(t234_perfmon_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = HWPM_ELEMENT_PERFMON,
		.element_index_mask = BIT(10),
		.element_index = 11U,
		.dt_mmio = NULL,
		.name = "perfmon_msschannel_partc2",
		.device_index = T234_MSS_CHANNEL_PARTC2_PERFMON_DEVICE_NODE_INDEX,
		.start_abs_pa = addr_map_rpg_pm_mss10_base_r(),
		.end_abs_pa = addr_map_rpg_pm_mss10_limit_r(),
		.start_pa = addr_map_rpg_pm_mss10_base_r(),
		.end_pa = addr_map_rpg_pm_mss10_limit_r(),
		.base_pa = addr_map_rpg_pm_base_r(),
		.alist = t234_perfmon_alist,
		.alist_size = ARRAY_SIZE(t234_perfmon_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = HWPM_ELEMENT_PERFMON,
		.element_index_mask = BIT(11),
		.element_index = 12U,
		.dt_mmio = NULL,
		.name = "perfmon_msschannel_partc3",
		.device_index = T234_MSS_CHANNEL_PARTC3_PERFMON_DEVICE_NODE_INDEX,
		.start_abs_pa = addr_map_rpg_pm_mss11_base_r(),
		.end_abs_pa = addr_map_rpg_pm_mss11_limit_r(),
		.start_pa = addr_map_rpg_pm_mss11_base_r(),
		.end_pa = addr_map_rpg_pm_mss11_limit_r(),
		.base_pa = addr_map_rpg_pm_base_r(),
		.alist = t234_perfmon_alist,
		.alist_size = ARRAY_SIZE(t234_perfmon_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = HWPM_ELEMENT_PERFMON,
		.element_index_mask = BIT(12),
		.element_index = 13U,
		.dt_mmio = NULL,
		.name = "perfmon_msschannel_partd0",
		.device_index = T234_MSS_CHANNEL_PARTD0_PERFMON_DEVICE_NODE_INDEX,
		.start_abs_pa = addr_map_rpg_pm_mss12_base_r(),
		.end_abs_pa = addr_map_rpg_pm_mss12_limit_r(),
		.start_pa = addr_map_rpg_pm_mss12_base_r(),
		.end_pa = addr_map_rpg_pm_mss12_limit_r(),
		.base_pa = addr_map_rpg_pm_base_r(),
		.alist = t234_perfmon_alist,
		.alist_size = ARRAY_SIZE(t234_perfmon_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = HWPM_ELEMENT_PERFMON,
		.element_index_mask = BIT(13),
		.element_index = 14U,
		.dt_mmio = NULL,
		.name = "perfmon_msschannel_partd1",
		.device_index = T234_MSS_CHANNEL_PARTD1_PERFMON_DEVICE_NODE_INDEX,
		.start_abs_pa = addr_map_rpg_pm_mss13_base_r(),
		.end_abs_pa = addr_map_rpg_pm_mss13_limit_r(),
		.start_pa = addr_map_rpg_pm_mss13_base_r(),
		.end_pa = addr_map_rpg_pm_mss13_limit_r(),
		.base_pa = addr_map_rpg_pm_base_r(),
		.alist = t234_perfmon_alist,
		.alist_size = ARRAY_SIZE(t234_perfmon_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = HWPM_ELEMENT_PERFMON,
		.element_index_mask = BIT(14),
		.element_index = 15U,
		.dt_mmio = NULL,
		.name = "perfmon_msschannel_partd2",
		.device_index = T234_MSS_CHANNEL_PARTD2_PERFMON_DEVICE_NODE_INDEX,
		.start_abs_pa = addr_map_rpg_pm_mss14_base_r(),
		.end_abs_pa = addr_map_rpg_pm_mss14_limit_r(),
		.start_pa = addr_map_rpg_pm_mss14_base_r(),
		.end_pa = addr_map_rpg_pm_mss14_limit_r(),
		.base_pa = addr_map_rpg_pm_base_r(),
		.alist = t234_perfmon_alist,
		.alist_size = ARRAY_SIZE(t234_perfmon_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = HWPM_ELEMENT_PERFMON,
		.element_index_mask = BIT(15),
		.element_index = 16U,
		.dt_mmio = NULL,
		.name = "perfmon_msschannel_partd3",
		.device_index = T234_MSS_CHANNEL_PARTD3_PERFMON_DEVICE_NODE_INDEX,
		.start_abs_pa = addr_map_rpg_pm_mss15_base_r(),
		.end_abs_pa = addr_map_rpg_pm_mss15_limit_r(),
		.start_pa = addr_map_rpg_pm_mss15_base_r(),
		.end_pa = addr_map_rpg_pm_mss15_limit_r(),
		.base_pa = addr_map_rpg_pm_base_r(),
		.alist = t234_perfmon_alist,
		.alist_size = ARRAY_SIZE(t234_perfmon_alist),
		.fake_registers = NULL,
	},
};

static struct hwpm_ip_aperture t234_mss_channel_inst0_perfmux_element_static_array[
	T234_HWPM_IP_MSS_CHANNEL_NUM_PERFMUX_PER_INST] = {
	{
		.element_type = IP_ELEMENT_PERFMUX,
		.element_index_mask = BIT(0),
		.element_index = 1U,
		.dt_mmio = NULL,
		.name = {'\0'},
		.start_abs_pa = addr_map_mc0_base_r(),
		.end_abs_pa = addr_map_mc0_limit_r(),
		.start_pa = addr_map_mc0_base_r(),
		.end_pa = addr_map_mc0_limit_r(),
		.base_pa = 0ULL,
		.alist = t234_mss_channel_alist,
		.alist_size = ARRAY_SIZE(t234_mss_channel_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = IP_ELEMENT_PERFMUX,
		.element_index_mask = BIT(1),
		.element_index = 2U,
		.dt_mmio = NULL,
		.name = {'\0'},
		.start_abs_pa = addr_map_mc1_base_r(),
		.end_abs_pa = addr_map_mc1_limit_r(),
		.start_pa = addr_map_mc1_base_r(),
		.end_pa = addr_map_mc1_limit_r(),
		.base_pa = 0ULL,
		.alist = t234_mss_channel_alist,
		.alist_size = ARRAY_SIZE(t234_mss_channel_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = IP_ELEMENT_PERFMUX,
		.element_index_mask = BIT(2),
		.element_index = 3U,
		.dt_mmio = NULL,
		.name = {'\0'},
		.start_abs_pa = addr_map_mc2_base_r(),
		.end_abs_pa = addr_map_mc2_limit_r(),
		.start_pa = addr_map_mc2_base_r(),
		.end_pa = addr_map_mc2_limit_r(),
		.base_pa = 0ULL,
		.alist = t234_mss_channel_alist,
		.alist_size = ARRAY_SIZE(t234_mss_channel_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = IP_ELEMENT_PERFMUX,
		.element_index_mask = BIT(3),
		.element_index = 4U,
		.dt_mmio = NULL,
		.name = {'\0'},
		.start_abs_pa = addr_map_mc3_base_r(),
		.end_abs_pa = addr_map_mc3_limit_r(),
		.start_pa = addr_map_mc3_base_r(),
		.end_pa = addr_map_mc3_limit_r(),
		.base_pa = 0ULL,
		.alist = t234_mss_channel_alist,
		.alist_size = ARRAY_SIZE(t234_mss_channel_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = IP_ELEMENT_PERFMUX,
		.element_index_mask = BIT(4),
		.element_index = 5U,
		.dt_mmio = NULL,
		.name = {'\0'},
		.start_abs_pa = addr_map_mc4_base_r(),
		.end_abs_pa = addr_map_mc4_limit_r(),
		.start_pa = addr_map_mc4_base_r(),
		.end_pa = addr_map_mc4_limit_r(),
		.base_pa = 0ULL,
		.alist = t234_mss_channel_alist,
		.alist_size = ARRAY_SIZE(t234_mss_channel_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = IP_ELEMENT_PERFMUX,
		.element_index_mask = BIT(5),
		.element_index = 6U,
		.dt_mmio = NULL,
		.name = {'\0'},
		.start_abs_pa = addr_map_mc5_base_r(),
		.end_abs_pa = addr_map_mc5_limit_r(),
		.start_pa = addr_map_mc5_base_r(),
		.end_pa = addr_map_mc5_limit_r(),
		.base_pa = 0ULL,
		.alist = t234_mss_channel_alist,
		.alist_size = ARRAY_SIZE(t234_mss_channel_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = IP_ELEMENT_PERFMUX,
		.element_index_mask = BIT(6),
		.element_index = 7U,
		.dt_mmio = NULL,
		.name = {'\0'},
		.start_abs_pa = addr_map_mc6_base_r(),
		.end_abs_pa = addr_map_mc6_limit_r(),
		.start_pa = addr_map_mc6_base_r(),
		.end_pa = addr_map_mc6_limit_r(),
		.base_pa = 0ULL,
		.alist = t234_mss_channel_alist,
		.alist_size = ARRAY_SIZE(t234_mss_channel_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = IP_ELEMENT_PERFMUX,
		.element_index_mask = BIT(7),
		.element_index = 8U,
		.dt_mmio = NULL,
		.name = {'\0'},
		.start_abs_pa = addr_map_mc7_base_r(),
		.end_abs_pa = addr_map_mc7_limit_r(),
		.start_pa = addr_map_mc7_base_r(),
		.end_pa = addr_map_mc7_limit_r(),
		.base_pa = 0ULL,
		.alist = t234_mss_channel_alist,
		.alist_size = ARRAY_SIZE(t234_mss_channel_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = IP_ELEMENT_PERFMUX,
		.element_index_mask = BIT(8),
		.element_index = 9U,
		.dt_mmio = NULL,
		.name = {'\0'},
		.start_abs_pa = addr_map_mc8_base_r(),
		.end_abs_pa = addr_map_mc8_limit_r(),
		.start_pa = addr_map_mc8_base_r(),
		.end_pa = addr_map_mc8_limit_r(),
		.base_pa = 0ULL,
		.alist = t234_mss_channel_alist,
		.alist_size = ARRAY_SIZE(t234_mss_channel_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = IP_ELEMENT_PERFMUX,
		.element_index_mask = BIT(9),
		.element_index = 10U,
		.dt_mmio = NULL,
		.name = {'\0'},
		.start_abs_pa = addr_map_mc9_base_r(),
		.end_abs_pa = addr_map_mc9_limit_r(),
		.start_pa = addr_map_mc9_base_r(),
		.end_pa = addr_map_mc9_limit_r(),
		.base_pa = 0ULL,
		.alist = t234_mss_channel_alist,
		.alist_size = ARRAY_SIZE(t234_mss_channel_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = IP_ELEMENT_PERFMUX,
		.element_index_mask = BIT(10),
		.element_index = 11U,
		.dt_mmio = NULL,
		.name = {'\0'},
		.start_abs_pa = addr_map_mc10_base_r(),
		.end_abs_pa = addr_map_mc10_limit_r(),
		.start_pa = addr_map_mc10_base_r(),
		.end_pa = addr_map_mc10_limit_r(),
		.base_pa = 0ULL,
		.alist = t234_mss_channel_alist,
		.alist_size = ARRAY_SIZE(t234_mss_channel_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = IP_ELEMENT_PERFMUX,
		.element_index_mask = BIT(11),
		.element_index = 12U,
		.dt_mmio = NULL,
		.name = {'\0'},
		.start_abs_pa = addr_map_mc11_base_r(),
		.end_abs_pa = addr_map_mc11_limit_r(),
		.start_pa = addr_map_mc11_base_r(),
		.end_pa = addr_map_mc11_limit_r(),
		.base_pa = 0ULL,
		.alist = t234_mss_channel_alist,
		.alist_size = ARRAY_SIZE(t234_mss_channel_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = IP_ELEMENT_PERFMUX,
		.element_index_mask = BIT(12),
		.element_index = 13U,
		.dt_mmio = NULL,
		.name = {'\0'},
		.start_abs_pa = addr_map_mc12_base_r(),
		.end_abs_pa = addr_map_mc12_limit_r(),
		.start_pa = addr_map_mc12_base_r(),
		.end_pa = addr_map_mc12_limit_r(),
		.base_pa = 0ULL,
		.alist = t234_mss_channel_alist,
		.alist_size = ARRAY_SIZE(t234_mss_channel_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = IP_ELEMENT_PERFMUX,
		.element_index_mask = BIT(13),
		.element_index = 14U,
		.dt_mmio = NULL,
		.name = {'\0'},
		.start_abs_pa = addr_map_mc13_base_r(),
		.end_abs_pa = addr_map_mc13_limit_r(),
		.start_pa = addr_map_mc13_base_r(),
		.end_pa = addr_map_mc13_limit_r(),
		.base_pa = 0ULL,
		.alist = t234_mss_channel_alist,
		.alist_size = ARRAY_SIZE(t234_mss_channel_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = IP_ELEMENT_PERFMUX,
		.element_index_mask = BIT(14),
		.element_index = 15U,
		.dt_mmio = NULL,
		.name = {'\0'},
		.start_abs_pa = addr_map_mc14_base_r(),
		.end_abs_pa = addr_map_mc14_limit_r(),
		.start_pa = addr_map_mc14_base_r(),
		.end_pa = addr_map_mc14_limit_r(),
		.base_pa = 0ULL,
		.alist = t234_mss_channel_alist,
		.alist_size = ARRAY_SIZE(t234_mss_channel_alist),
		.fake_registers = NULL,
	},
	{
		.element_type = IP_ELEMENT_PERFMUX,
		.element_index_mask = BIT(15),
		.element_index = 16U,
		.dt_mmio = NULL,
		.name = {'\0'},
		.start_abs_pa = addr_map_mc15_base_r(),
		.end_abs_pa = addr_map_mc15_limit_r(),
		.start_pa = addr_map_mc15_base_r(),
		.end_pa = addr_map_mc15_limit_r(),
		.base_pa = 0ULL,
		.alist = t234_mss_channel_alist,
		.alist_size = ARRAY_SIZE(t234_mss_channel_alist),
		.fake_registers = NULL,
	},
};

static struct hwpm_ip_aperture t234_mss_channel_inst0_broadcast_element_static_array[
	T234_HWPM_IP_MSS_CHANNEL_NUM_BROADCAST_PER_INST] = {
	{
		.element_type = IP_ELEMENT_BROADCAST,
		.element_index_mask = BIT(0),
		.element_index = 0U,
		.dt_mmio = NULL,
		.name = {'\0'},
		.start_abs_pa = addr_map_mcb_base_r(),
		.end_abs_pa = addr_map_mcb_limit_r(),
		.start_pa = addr_map_mcb_base_r(),
		.end_pa = addr_map_mcb_limit_r(),
		.base_pa = 0ULL,
		.alist = t234_mss_channel_alist,
		.alist_size = ARRAY_SIZE(t234_mss_channel_alist),
		.fake_registers = NULL,
	},
};

/* IP instance array */
static struct hwpm_ip_inst t234_mss_channel_inst_static_array[
	T234_HWPM_IP_MSS_CHANNEL_NUM_INSTANCES] = {
	{
		.hw_inst_mask = BIT(0),
		.num_core_elements_per_inst =
			T234_HWPM_IP_MSS_CHANNEL_NUM_CORE_ELEMENT_PER_INST,
		.element_info = {
			/*
			 * Instance info corresponding to
			 * TEGRA_HWPM_APERTURE_TYPE_PERFMUX
			 */
			{
				.num_element_per_inst =
					T234_HWPM_IP_MSS_CHANNEL_NUM_PERFMUX_PER_INST,
				.element_static_array =
					t234_mss_channel_inst0_perfmux_element_static_array,
				/* NOTE: range should be in ascending order */
				.range_start = addr_map_mc8_base_r(),
				.range_end = addr_map_mc3_limit_r(),
				.element_stride = addr_map_mc0_limit_r() -
					addr_map_mc0_base_r() + 1ULL,
				.element_slots = 0U,
				.element_arr = NULL,
			},
			/*
			 * Instance info corresponding to
			 * TEGRA_HWPM_APERTURE_TYPE_BROADCAST
			 */
			{
				.num_element_per_inst =
					T234_HWPM_IP_MSS_CHANNEL_NUM_BROADCAST_PER_INST,
				.element_static_array =
					t234_mss_channel_inst0_broadcast_element_static_array,
				.range_start = addr_map_mcb_base_r(),
				.range_end = addr_map_mcb_limit_r(),
				.element_stride = addr_map_mcb_limit_r() -
					addr_map_mcb_base_r() + 1ULL,
				.element_slots = 0U,
				.element_arr = NULL,
			},
			/*
			 * Instance info corresponding to
			 * TEGRA_HWPM_APERTURE_TYPE_PERFMON
			 */
			{
				.num_element_per_inst =
					T234_HWPM_IP_MSS_CHANNEL_NUM_PERFMON_PER_INST,
				.element_static_array =
					t234_mss_channel_inst0_perfmon_element_static_array,
				.range_start = addr_map_rpg_pm_mss0_base_r(),
				.range_end = addr_map_rpg_pm_mss15_limit_r(),
				.element_stride = addr_map_rpg_pm_mss0_limit_r() -
					addr_map_rpg_pm_mss0_base_r() + 1ULL,
				.element_slots = 0U,
				.element_arr = NULL,
			},
		},

		.ip_ops = {
			.ip_dev = NULL,
			.hwpm_ip_pm = NULL,
			.hwpm_ip_reg_op = NULL,
			.fd = -1,
		},

		.element_fs_mask = 0U,
		.dev_name = "",
	},
};

/* IP structure */
struct hwpm_ip t234_hwpm_ip_mss_channel = {
	.num_instances = T234_HWPM_IP_MSS_CHANNEL_NUM_INSTANCES,
	.ip_inst_static_array = t234_mss_channel_inst_static_array,

	.inst_aperture_info = {
		/*
		 * Instance info corresponding to
		 * TEGRA_HWPM_APERTURE_TYPE_PERFMUX
		 */
		{
			/* NOTE: range should be in ascending order */
			.range_start = addr_map_mc8_base_r(),
			.range_end = addr_map_mc3_limit_r(),
			.inst_stride = addr_map_mc3_limit_r() -
				addr_map_mc8_base_r() + 1ULL,
			.inst_slots = 0U,
			.inst_arr = NULL,
		},
		/*
		 * Instance info corresponding to
		 * TEGRA_HWPM_APERTURE_TYPE_BROADCAST
		 */
		{
			.range_start = addr_map_mcb_base_r(),
			.range_end = addr_map_mcb_limit_r(),
			.inst_stride = addr_map_mcb_limit_r() -
				addr_map_mcb_base_r() + 1ULL,
			.inst_slots = 0U,
			.inst_arr = NULL,
		},
		/*
		 * Instance info corresponding to
		 * TEGRA_HWPM_APERTURE_TYPE_PERFMON
		 */
		{
			.range_start = addr_map_rpg_pm_mss0_base_r(),
			.range_end = addr_map_rpg_pm_mss15_limit_r(),
			.inst_stride = addr_map_rpg_pm_mss15_limit_r() -
				addr_map_rpg_pm_mss0_base_r() + 1ULL,
			.inst_slots = 0U,
			.inst_arr = NULL,
		},
	},

	.dependent_fuse_mask = TEGRA_HWPM_FUSE_HWPM_GLOBAL_DISABLE_MASK,
	.override_enable = false,
	.inst_fs_mask = 0U,
	.resource_status = TEGRA_HWPM_RESOURCE_STATUS_INVALID,
	.reserved = false,
};
