/*
 * Copyright (c) 2020-2023, NVIDIA CORPORATION.  All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
/*
 * Function/Macro naming determines intended use:
 *
 *     <x>_r(void) : Returns the offset for register <x>.
 *
 *     <x>_o(void) : Returns the offset for element <x>.
 *
 *     <x>_w(void) : Returns the word offset for word (4 byte) element <x>.
 *
 *     <x>_<y>_s(void) : Returns size of field <y> of register <x> in bits.
 *
 *     <x>_<y>_f(u32 v) : Returns a value based on 'v' which has been shifted
 *         and masked to place it at field <y> of register <x>.  This value
 *         can be |'d with others to produce a full register value for
 *         register <x>.
 *
 *     <x>_<y>_m(void) : Returns a mask for field <y> of register <x>.  This
 *         value can be ~'d and then &'d to clear the value of field <y> for
 *         register <x>.
 *
 *     <x>_<y>_<z>_f(void) : Returns the constant value <z> after being shifted
 *         to place it at field <y> of register <x>.  This value can be |'d
 *         with others to produce a full register value for <x>.
 *
 *     <x>_<y>_v(u32 r) : Returns the value of field <y> from a full register
 *         <x> value 'r' after being shifted to place its LSB at bit 0.
 *         This value is suitable for direct comparison with other unshifted
 *         values appropriate for use in field <y> of register <x>.
 *
 *     <x>_<y>_<z>_v(void) : Returns the constant value for <z> defined for
 *         field <y> of register <x>.  This value is suitable for direct
 *         comparison with unshifted values appropriate for use in field <y>
 *         of register <x>.
 */
#ifndef NVGPU_HW_GR_GA100_H
#define NVGPU_HW_GR_GA100_H

#include <nvgpu/types.h>
#include <nvgpu/static_analysis.h>

#define gr_intr_notify_ctrl_r()                                    (0x00400160U)
#define gr_intr_notify_ctrl_vector_f(v)                ((U32(v) & 0xfffU) << 0U)
#define gr_intr_notify_ctrl_cpu_enable_f()                         (0x80000000U)
#define gr_intr_notify_ctrl_gsp_enable_f()                         (0x40000000U)
#define gr_intr_r()                                                (0x00400100U)
#define gr_intr_notify_pending_f()                                        (0x1U)
#define gr_intr_semaphore_pending_f()                                     (0x2U)
#define gr_intr_illegal_method_pending_f()                               (0x10U)
#define gr_intr_illegal_class_pending_f()                                (0x20U)
#define gr_intr_illegal_notify_pending_f()                               (0x40U)
#define gr_intr_debug_method_pending_f()                                 (0x80U)
#define gr_intr_firmware_method_pending_f()                             (0x100U)
#define gr_intr_buffer_notify_pending_f()                             (0x10000U)
#define gr_intr_fecs_error_pending_f()                                (0x80000U)
#define gr_intr_class_error_pending_f()                              (0x100000U)
#define gr_intr_exception_pending_f()                                (0x200000U)
#define gr_fecs_intr_r()                                           (0x00400144U)
#define gr_class_error_r()                                         (0x00400110U)
#define gr_class_error_code_v(r)                         (((r) >> 0U) & 0xffffU)
#define gr_intr_en_r()                                             (0x0040013cU)
#define gr_intr_en_notify__prod_f()                                       (0x1U)
#define gr_intr_en_semaphore__prod_f()                                    (0x2U)
#define gr_intr_en_illegal_method__prod_f()                              (0x10U)
#define gr_intr_en_illegal_class__prod_f()                               (0x20U)
#define gr_intr_en_illegal_notify__prod_f()                              (0x40U)
#define gr_intr_en_debug_method__prod_f()                                (0x80U)
#define gr_intr_en_firmware_method__prod_f()                            (0x100U)
#define gr_intr_en_buffer_notify__prod_f()                            (0x10000U)
#define gr_intr_en_fecs_error__prod_f()                               (0x80000U)
#define gr_intr_en_class_error__prod_f()                             (0x100000U)
#define gr_intr_en_exception__prod_f()                               (0x200000U)
#define gr_intr_en_fe_debug_intr__prod_f()                           (0x400000U)
#define gr_intr_retrigger_r()                                      (0x00400158U)
#define gr_intr_retrigger_trigger_true_f()                                (0x1U)
#define gr_exception_r()                                           (0x00400108U)
#define gr_exception_fe_m()                                    (U32(0x1U) << 0U)
#define gr_exception_gpc_m()                                  (U32(0x1U) << 24U)
#define gr_exception_memfmt_m()                                (U32(0x1U) << 1U)
#define gr_exception_ds_m()                                    (U32(0x1U) << 4U)
#define gr_exception_sked_m()                                  (U32(0x1U) << 8U)
#define gr_exception_pd_m()                                    (U32(0x1U) << 2U)
#define gr_exception_scc_m()                                   (U32(0x1U) << 3U)
#define gr_exception_ssync_m()                                 (U32(0x1U) << 5U)
#define gr_exception_mme_m()                                   (U32(0x1U) << 7U)
#define gr_exception1_r()                                          (0x00400118U)
#define gr_exception1_gpc_0_pending_f()                                   (0x1U)
#define gr_exception_en_r()                                        (0x00400138U)
#define gr_exception_en_fe_enabled_f()                                    (0x1U)
#define gr_exception_en_gpc_enabled_f()                             (0x1000000U)
#define gr_exception_en_memfmt_enabled_f()                                (0x2U)
#define gr_exception_en_ds_enabled_f()                                   (0x10U)
#define gr_exception_en_pd_enabled_f()                                    (0x4U)
#define gr_exception_en_scc_enabled_f()                                   (0x8U)
#define gr_exception_en_ssync_enabled_f()                                (0x20U)
#define gr_exception_en_mme_enabled_f()                                  (0x80U)
#define gr_exception_en_sked_enabled_f()                                (0x100U)
#define gr_exception1_en_r()                                       (0x00400130U)
#define gr_gpfifo_ctl_r()                                          (0x00400500U)
#define gr_gpfifo_ctl_access_f(v)                        ((U32(v) & 0x1U) << 0U)
#define gr_gpfifo_ctl_access_enabled_f()                                  (0x1U)
#define gr_gpfifo_ctl_semaphore_access_f(v)             ((U32(v) & 0x1U) << 16U)
#define gr_gpfifo_ctl_semaphore_access_enabled_f()                    (0x10000U)
#define gr_gpfifo_status_r()                                       (0x00400504U)
#define gr_trapped_addr_r()                                        (0x00400704U)
#define gr_trapped_addr_mthd_v(r)                         (((r) >> 2U) & 0xfffU)
#define gr_trapped_addr_subch_v(r)                         (((r) >> 16U) & 0x7U)
#define gr_trapped_addr_mme_generated_v(r)                 (((r) >> 20U) & 0x1U)
#define gr_trapped_addr_datahigh_v(r)                      (((r) >> 24U) & 0x1U)
#define gr_trapped_addr_priv_v(r)                          (((r) >> 28U) & 0x1U)
#define gr_trapped_data_lo_r()                                     (0x00400708U)
#define gr_trapped_data_hi_r()                                     (0x0040070cU)
#define gr_trapped_data_mme_r()                                    (0x00400710U)
#define gr_trapped_data_mme_pc_v(r)                       (((r) >> 0U) & 0xfffU)
#define gr_status_r()                                              (0x00400700U)
#define gr_status_state_v(r)                                (((r) >> 0U) & 0x1U)
#define gr_status_state_busy_v()                                   (0x00000001U)
#define gr_status_fe_method_upper_v(r)                      (((r) >> 1U) & 0x1U)
#define gr_status_fe_method_upper_busy_v()                         (0x00000001U)
#define gr_status_fe_method_lower_v(r)                      (((r) >> 2U) & 0x1U)
#define gr_status_fe_method_lower_busy_v()                         (0x00000001U)
#define gr_status_1_r()                                            (0x00400604U)
#define gr_engine_config_r()                                       (0x00400614U)
#define gr_engine_config_supported_3d_true_f()                            (0x1U)
#define gr_engine_config_supported_compute_true_f()                       (0x2U)
#define gr_engine_config_supported_i2m_true_f()                           (0x4U)
#define gr_engine_config_supported_2d_true_f()                            (0x8U)
#define gr_engine_status_r()                                       (0x0040060cU)
#define gr_engine_status_value_busy_f()                                   (0x1U)
#define gr_pri_gpc0_gpccs_gpc_exception_r()                        (0x00502c90U)
#define gr_pri_gpc0_gpccs_gpc_exception_en_r()                     (0x00502c94U)
#define gr_pri_gpc0_tpc0_tpccs_tpc_exception_r()                   (0x00504508U)
#define gr_pri_gpc0_tpc0_tpccs_tpc_exception_en_r()                (0x0050450cU)
#define gr_activity_0_r()                                          (0x00400380U)
#define gr_activity_1_r()                                          (0x00400384U)
#define gr_activity_1_memfmt_b()                                            (6U)
#define gr_activity_4_r()                                          (0x00400390U)
#define gr_activity_4_gpc0_s()                                              (3U)
#define gr_activity_4_gpc0_v(r)                             (((r) >> 0U) & 0x7U)
#define gr_activity_4_gpc0_empty_v()                               (0x00000000U)
#define gr_activity_4_gpc0_preempted_v()                           (0x00000004U)
#define gr_pri_sked_activity_r()                                   (0x00407054U)
#define gr_pri_gpc0_gpccs_gpc_activity0_r()                        (0x00502c80U)
#define gr_pri_gpc0_gpccs_gpc_activity1_r()                        (0x00502c84U)
#define gr_pri_gpc0_gpccs_gpc_activity2_r()                        (0x00502c88U)
#define gr_pri_gpc0_gpccs_gpc_activity3_r()                        (0x00502c8cU)
#define gr_pri_gpc0_tpc0_tpccs_tpc_activity_0_r()                  (0x00504500U)
#define gr_pri_gpcs_gpccs_gpc_activity_0_r()                       (0x0041ac80U)
#define gr_pri_gpcs_gpccs_gpc_activity_1_r()                       (0x0041ac84U)
#define gr_pri_gpcs_gpccs_gpc_activity_2_r()                       (0x0041ac88U)
#define gr_pri_gpcs_gpccs_gpc_activity_3_r()                       (0x0041ac8cU)
#define gr_pri_gpcs_tpcs_tpccs_tpc_activity_0_r()                  (0x00419d00U)
#define gr_pri_ds_mpipe_status_r()                                 (0x00405858U)
#define gr_pri_fe_go_idle_info_r()                                 (0x00404194U)
#define gr_pri_fe_chip_def_info_r()                                (0x00404030U)
#define gr_pri_fe_chip_def_info_max_veid_count_init_v()            (0x00000040U)
#define gr_pri_gpc0_tpc0_tex_m_tex_subunits_status_r()             (0x00504238U)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_status_r()                     (0x00504358U)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_status_corrected_err_qrfdp0_m()\
				(U32(0x1U) << 0U)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_status_corrected_err_qrfdp1_m()\
				(U32(0x1U) << 1U)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_status_corrected_err_qrfdp2_m()\
				(U32(0x1U) << 2U)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_status_corrected_err_qrfdp3_m()\
				(U32(0x1U) << 3U)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_status_uncorrected_err_qrfdp0_m()\
				(U32(0x1U) << 8U)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_status_uncorrected_err_qrfdp1_m()\
				(U32(0x1U) << 9U)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_status_uncorrected_err_qrfdp2_m()\
				(U32(0x1U) << 10U)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_status_uncorrected_err_qrfdp3_m()\
				(U32(0x1U) << 11U)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_status_corrected_err_total_counter_overflow_v(r)\
				(((r) >> 24U) & 0x1U)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_status_uncorrected_err_total_counter_overflow_v(r)\
				(((r) >> 26U) & 0x1U)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_status_reset_task_f()          (0x40000000U)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_corrected_err_count_r()        (0x0050435cU)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_corrected_err_count_total_v(r)\
				(((r) >> 0U) & 0xffffU)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_uncorrected_err_count_r()      (0x00504360U)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_uncorrected_err_count_total_s()        (16U)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_uncorrected_err_count_total_v(r)\
				(((r) >> 0U) & 0xffffU)
#define gr_pri_gpc0_tpc0_sm_l1_data_ecc_status_r()                 (0x0050436cU)
#define gr_pri_gpc0_tpc0_sm_l1_data_ecc_status_corrected_err_el1_0_m()\
				(U32(0x1U) << 0U)
#define gr_pri_gpc0_tpc0_sm_l1_data_ecc_status_uncorrected_err_el1_0_m()\
				(U32(0x1U) << 2U)
#define gr_pri_gpc0_tpc0_sm_l1_data_ecc_status_corrected_err_total_counter_overflow_v(r)\
				(((r) >> 8U) & 0x1U)
#define gr_pri_gpc0_tpc0_sm_l1_data_ecc_status_uncorrected_err_total_counter_overflow_v(r)\
				(((r) >> 10U) & 0x1U)
#define gr_pri_gpc0_tpc0_sm_l1_data_ecc_status_reset_task_f()      (0x40000000U)
#define gr_pri_gpc0_tpc0_sm_l1_data_ecc_corrected_err_count_r()    (0x00504370U)
#define gr_pri_gpc0_tpc0_sm_l1_data_ecc_corrected_err_count_total_v(r)\
				(((r) >> 0U) & 0xffffU)
#define gr_pri_gpc0_tpc0_sm_l1_data_ecc_uncorrected_err_count_r()  (0x00504374U)
#define gr_pri_gpc0_tpc0_sm_l1_data_ecc_uncorrected_err_count_total_s()    (16U)
#define gr_pri_gpc0_tpc0_sm_l1_data_ecc_uncorrected_err_count_total_v(r)\
				(((r) >> 0U) & 0xffffU)
#define gr_pri_gpc0_tpc0_sm_cbu_ecc_status_r()                     (0x00504638U)
#define gr_pri_gpc0_tpc0_sm_cbu_ecc_status_corrected_err_warp_sm0_m()\
				(U32(0x1U) << 0U)
#define gr_pri_gpc0_tpc0_sm_cbu_ecc_status_corrected_err_barrier_sm0_m()\
				(U32(0x1U) << 2U)
#define gr_pri_gpc0_tpc0_sm_cbu_ecc_status_uncorrected_err_warp_sm0_m()\
				(U32(0x1U) << 4U)
#define gr_pri_gpc0_tpc0_sm_cbu_ecc_status_uncorrected_err_barrier_sm0_m()\
				(U32(0x1U) << 6U)
#define gr_pri_gpc0_tpc0_sm_cbu_ecc_status_corrected_err_total_counter_overflow_v(r)\
				(((r) >> 16U) & 0x1U)
#define gr_pri_gpc0_tpc0_sm_cbu_ecc_status_uncorrected_err_total_counter_overflow_v(r)\
				(((r) >> 18U) & 0x1U)
#define gr_pri_gpc0_tpc0_sm_cbu_ecc_status_reset_task_f()          (0x40000000U)
#define gr_pri_gpc0_tpc0_sm_cbu_ecc_corrected_err_count_r()        (0x0050463cU)
#define gr_pri_gpc0_tpc0_sm_cbu_ecc_corrected_err_count_total_v(r)\
				(((r) >> 0U) & 0xffffU)
#define gr_pri_gpc0_tpc0_sm_cbu_ecc_uncorrected_err_count_r()      (0x00504640U)
#define gr_pri_gpc0_tpc0_sm_cbu_ecc_uncorrected_err_count_total_s()        (16U)
#define gr_pri_gpc0_tpc0_sm_cbu_ecc_uncorrected_err_count_total_v(r)\
				(((r) >> 0U) & 0xffffU)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_status_r()                  (0x00504624U)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_status_corrected_err_el1_0_m()\
				(U32(0x1U) << 0U)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_status_uncorrected_err_el1_0_m()\
				(U32(0x1U) << 2U)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_status_corrected_err_pixrpf_m()\
				(U32(0x1U) << 4U)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_status_corrected_err_miss_fifo_m()\
				(U32(0x1U) << 5U)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_status_uncorrected_err_pixrpf_m()\
				(U32(0x1U) << 6U)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_status_uncorrected_err_miss_fifo_m()\
				(U32(0x1U) << 7U)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_status_corrected_err_total_counter_overflow_v(r)\
				(((r) >> 8U) & 0x1U)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_status_uncorrected_err_total_counter_overflow_v(r)\
				(((r) >> 10U) & 0x1U)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_status_reset_task_f()       (0x40000000U)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_corrected_err_count_r()     (0x00504628U)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_corrected_err_count_total_s()       (16U)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_corrected_err_count_total_v(r)\
				(((r) >> 0U) & 0xffffU)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_uncorrected_err_count_r()   (0x0050462cU)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_uncorrected_err_count_total_s()     (16U)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_uncorrected_err_count_total_v(r)\
				(((r) >> 0U) & 0xffffU)
#define gr_pri_gpc0_tpc0_sm_icache_ecc_status_r()                  (0x0050464cU)
#define gr_pri_gpc0_tpc0_sm_icache_ecc_status_corrected_err_l1_data_m()\
				(U32(0x1U) << 2U)
#define gr_pri_gpc0_tpc0_sm_icache_ecc_status_uncorrected_err_l1_data_m()\
				(U32(0x1U) << 6U)
#define gr_pri_gpc0_tpc0_sm_icache_ecc_status_corrected_err_total_counter_overflow_v(r)\
				(((r) >> 16U) & 0x1U)
#define gr_pri_gpc0_tpc0_sm_icache_ecc_status_uncorrected_err_total_counter_overflow_v(r)\
				(((r) >> 18U) & 0x1U)
#define gr_pri_gpc0_tpc0_sm_icache_ecc_status_reset_task_f()       (0x40000000U)
#define gr_pri_gpc0_tpc0_sm_icache_ecc_corrected_err_count_r()     (0x00504650U)
#define gr_pri_gpc0_tpc0_sm_icache_ecc_corrected_err_count_total_s()       (16U)
#define gr_pri_gpc0_tpc0_sm_icache_ecc_corrected_err_count_total_v(r)\
				(((r) >> 0U) & 0xffffU)
#define gr_pri_gpc0_tpc0_sm_icache_ecc_uncorrected_err_count_r()   (0x00504654U)
#define gr_pri_gpc0_tpc0_sm_icache_ecc_uncorrected_err_count_total_s()     (16U)
#define gr_pri_gpc0_tpc0_sm_icache_ecc_uncorrected_err_count_total_v(r)\
				(((r) >> 0U) & 0xffffU)
#define gr_pri_gpc0_tpc0_sm_rams_ecc_status_r()                    (0x00504388U)
#define gr_pri_gpc0_tpc0_sm_rams_ecc_status_corrected_err_l0ic_data_m()\
				(U32(0x1U) << 0U)
#define gr_pri_gpc0_tpc0_sm_rams_ecc_status_uncorrected_err_l0ic_data_m()\
				(U32(0x1U) << 8U)
#define gr_pri_gpc0_tpc0_sm_rams_ecc_status_corrected_err_l0ic_predecode_m()\
				(U32(0x1U) << 1U)
#define gr_pri_gpc0_tpc0_sm_rams_ecc_status_uncorrected_err_l0ic_predecode_m()\
				(U32(0x1U) << 9U)
#define gr_pri_gpc0_tpc0_sm_rams_ecc_status_corrected_err_urf_data_m()\
				(U32(0x1U) << 2U)
#define gr_pri_gpc0_tpc0_sm_rams_ecc_status_uncorrected_err_urf_data_m()\
				(U32(0x1U) << 10U)
#define gr_pri_gpc0_tpc0_sm_rams_ecc_status_corrected_err_total_counter_overflow_v(r)\
				(((r) >> 24U) & 0x1U)
#define gr_pri_gpc0_tpc0_sm_rams_ecc_status_uncorrected_err_total_counter_overflow_v(r)\
				(((r) >> 26U) & 0x1U)
#define gr_pri_gpc0_tpc0_sm_rams_ecc_status_reset_task_f()         (0x40000000U)
#define gr_pri_gpc0_tpc0_sm_rams_ecc_corrected_err_count_r()       (0x0050438cU)
#define gr_pri_gpc0_tpc0_sm_rams_ecc_corrected_err_count_total_s()         (16U)
#define gr_pri_gpc0_tpc0_sm_rams_ecc_corrected_err_count_total_v(r)\
				(((r) >> 0U) & 0xffffU)
#define gr_pri_gpc0_tpc0_sm_rams_ecc_uncorrected_err_count_r()     (0x00504390U)
#define gr_pri_gpc0_tpc0_sm_rams_ecc_uncorrected_err_count_total_s()       (16U)
#define gr_pri_gpc0_tpc0_sm_rams_ecc_uncorrected_err_count_total_v(r)\
				(((r) >> 0U) & 0xffffU)
#define gr_pri_gpcs_tpcs_sm_lrf_ecc_control_r()                    (0x00419b54U)
#define gr_pri_gpcs_tpcs_sm_lrf_ecc_control_scrub_qrfdp0_task_f()         (0x1U)
#define gr_pri_gpcs_tpcs_sm_lrf_ecc_control_scrub_qrfdp1_task_f()         (0x2U)
#define gr_pri_gpcs_tpcs_sm_lrf_ecc_control_scrub_qrfdp2_task_f()         (0x4U)
#define gr_pri_gpcs_tpcs_sm_lrf_ecc_control_scrub_qrfdp3_task_f()         (0x8U)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_control_r()                    (0x00504354U)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_control_scrub_qrfdp0_init_f()         (0x0U)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_control_scrub_qrfdp1_init_f()         (0x0U)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_control_scrub_qrfdp2_init_f()         (0x0U)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_control_scrub_qrfdp3_init_f()         (0x0U)
#define gr_pri_gpc0_tpc0_sm_lrf_ecc_control_inject_uncorrected_err_f(v)\
				((U32(v) & 0x1U) << 9U)
#define gr_pri_gpcs_tpcs_sm_l1_data_ecc_control_r()                (0x00419b68U)
#define gr_pri_gpcs_tpcs_sm_l1_data_ecc_control_scrub_el1_0_task_f()      (0x1U)
#define gr_pri_gpc0_tpc0_sm_l1_data_ecc_control_r()                (0x00504368U)
#define gr_pri_gpc0_tpc0_sm_l1_data_ecc_control_scrub_el1_0_init_f()      (0x0U)
#define gr_pri_gpc0_tpc0_sm_l1_data_ecc_control_inject_uncorrected_err_f(v)\
				((U32(v) & 0x1U) << 3U)
#define gr_pri_gpcs_tpcs_sm_l1_tag_ecc_control_r()                 (0x00419e20U)
#define gr_pri_gpcs_tpcs_sm_l1_tag_ecc_control_scrub_el1_0_task_f()       (0x1U)
#define gr_pri_gpcs_tpcs_sm_l1_tag_ecc_control_scrub_pixprf_task_f()     (0x10U)
#define gr_pri_gpcs_tpcs_sm_l1_tag_ecc_control_scrub_miss_fifo_task_f()  (0x20U)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_control_r()                 (0x00504620U)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_control_scrub_el1_0_init_f()       (0x0U)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_control_inject_corrected_err_f(v)\
				((U32(v) & 0x1U) << 2U)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_control_inject_uncorrected_err_f(v)\
				((U32(v) & 0x1U) << 3U)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_control_scrub_pixprf_init_f()      (0x0U)
#define gr_pri_gpc0_tpc0_sm_l1_tag_ecc_control_scrub_miss_fifo_init_f()   (0x0U)
#define gr_pri_gpcs_tpcs_sm_cbu_ecc_control_r()                    (0x00419e34U)
#define gr_pri_gpcs_tpcs_sm_cbu_ecc_control_scrub_warp_sm0_task_f()       (0x1U)
#define gr_pri_gpcs_tpcs_sm_cbu_ecc_control_scrub_barrier_sm0_task_f()    (0x4U)
#define gr_pri_gpc0_tpc0_sm_cbu_ecc_control_r()                    (0x00504634U)
#define gr_pri_gpc0_tpc0_sm_cbu_ecc_control_scrub_warp_sm0_init_f()       (0x0U)
#define gr_pri_gpc0_tpc0_sm_cbu_ecc_control_scrub_barrier_sm0_init_f()    (0x0U)
#define gr_pri_gpc0_tpc0_sm_cbu_ecc_control_inject_uncorrected_err_f(v)\
				((U32(v) & 0x1U) << 5U)
#define gr_pri_gpcs_tpcs_sm_icache_ecc_control_r()                 (0x00419e48U)
#define gr_pri_gpcs_tpcs_sm_icache_ecc_control_scrub_l1_data_task_f()     (0x4U)
#define gr_pri_gpc0_tpc0_sm_icache_ecc_control_r()                 (0x00504648U)
#define gr_pri_gpc0_tpc0_sm_icache_ecc_control_scrub_l1_data_init_f()     (0x0U)
#define gr_pri_gpc0_tpc0_sm_icache_ecc_control_inject_uncorrected_err_f(v)\
				((U32(v) & 0x1U) << 5U)
#define gr_pri_gpcs_tpcs_sm_rams_ecc_control_r()                   (0x00419b84U)
#define gr_pri_gpcs_tpcs_sm_rams_ecc_control_scrub_l0ic_data_task_f()     (0x1U)
#define gr_pri_gpcs_tpcs_sm_rams_ecc_control_scrub_l0ic_predecode_task_f()\
				(0x2U)
#define gr_pri_gpcs_tpcs_sm_rams_ecc_control_scrub_urf_data_task_f()      (0x4U)
#define gr_pri_gpc0_tpc0_sm_rams_ecc_control_r()                   (0x00504384U)
#define gr_pri_gpc0_tpc0_sm_rams_ecc_control_scrub_l0ic_data_init_f()     (0x0U)
#define gr_pri_gpc0_tpc0_sm_rams_ecc_control_scrub_l0ic_predecode_init_f()\
				(0x0U)
#define gr_pri_gpc0_tpc0_sm_rams_ecc_control_scrub_urf_data_init_f()      (0x0U)
#define gr_pri_gpc0_tpc0_tex_m_routing_r()                         (0x005042c4U)
#define gr_pri_gpc0_tpc0_tex_m_routing_sel_default_f()                    (0x0U)
#define gr_pri_gpc0_tpc0_tex_m_routing_sel_pipe0_f()                      (0x1U)
#define gr_pri_gpc0_tpc0_tex_m_routing_sel_pipe1_f()                      (0x2U)
#define gr_pipe_bundle_address_r()                                 (0x00400200U)
#define gr_pipe_bundle_address_value_v(r)                (((r) >> 0U) & 0xffffU)
#define gr_pipe_bundle_address_veid_f(v)               ((U32(v) & 0x3fU) << 20U)
#define gr_pipe_bundle_data_r()                                    (0x00400204U)
#define gr_pipe_bundle_data_hi_r()                                 (0x0040020cU)
#define gr_pipe_bundle_config_r()                                  (0x00400208U)
#define gr_pipe_bundle_config_override_pipe_mode_disabled_f()             (0x0U)
#define gr_pipe_bundle_config_override_pipe_mode_enabled_f()       (0x80000000U)
#define gr_gpc0_tpc0_mpc_hww_esr_r()                               (0x00504430U)
#define gr_gpc0_tpc0_mpc_hww_esr_reset_trigger_f()                 (0x40000000U)
#define gr_gpc0_tpc0_mpc_hww_esr_info_r()                          (0x00504434U)
#define gr_gpc0_tpc0_mpc_hww_esr_info_veid_v(r)            (((r) >> 0U) & 0x3fU)
#define gr_gpc0_tpc0_pe_hww_esr_r()                                (0x00504084U)
#define gr_gpc0_tpc0_pe_hww_esr_reset_task_f()                     (0x40000000U)
#define gr_gpc0_prop_hww_esr_r()                                   (0x00500420U)
#define gr_gpc0_prop_hww_esr_reset_active_f()                      (0x40000000U)
#define gr_gpc0_prop_hww_esr_coord_r()                             (0x00500434U)
#define gr_gpc0_prop_hww_esr_format_r()                            (0x00500438U)
#define gr_gpc0_prop_hww_esr_state_r()                             (0x0050043cU)
#define gr_gpc0_prop_hww_esr_state2_r()                            (0x00500440U)
#define gr_gpc0_prop_hww_esr_offset_r()                            (0x00500444U)
#define gr_gpc0_zcull_hww_esr_r()                                  (0x00500900U)
#define gr_gpc0_zcull_hww_esr_reset_active_f()                     (0x40000000U)
#define gr_gpc0_setup_hww_esr_r()                                  (0x00500824U)
#define gr_gpc0_setup_hww_esr_reset_active_f()                     (0x40000000U)
#define gr_gpc0_ppc0_pes_hww_esr_r()                               (0x00503038U)
#define gr_gpc0_ppc0_pes_hww_esr_reset_task_f()                    (0x40000000U)
#define gr_gpc0_gpccs_hww_esr_r()                                  (0x00502c98U)
#define gr_gpc0_gpccs_hww_esr_ecc_corrected_m()                (U32(0x1U) << 0U)
#define gr_gpc0_gpccs_hww_esr_ecc_uncorrected_m()              (U32(0x1U) << 1U)
#define gr_gpccs_falcon_ecc_control_r()                            (0x0050268cU)
#define gr_gpccs_falcon_ecc_control_inject_corrected_err_f(v)\
				((U32(v) & 0x1U) << 0U)
#define gr_gpccs_falcon_ecc_control_inject_uncorrected_err_f(v)\
				((U32(v) & 0x1U) << 1U)
#define gr_fe_hww_esr_r()                                          (0x00404000U)
#define gr_fe_hww_esr_reset_active_f()                             (0x40000000U)
#define gr_fe_hww_esr_en_enable_f()                                (0x80000000U)
#define gr_fe_hww_esr_info_r()                                     (0x004041b0U)
#define gr_gpcs_tpcs_sms_hww_global_esr_report_mask_r()            (0x00419eacU)
#define gr_gpc0_tpc0_sm0_hww_global_esr_report_mask_r()            (0x0050472cU)
#define gr_gpc0_tpc0_sm0_hww_global_esr_report_mask_multiple_warp_errors_report_f()\
				(0x4U)
#define gr_gpc0_tpc0_sm0_hww_global_esr_report_mask_bpt_int_report_f()   (0x10U)
#define gr_gpc0_tpc0_sm0_hww_global_esr_report_mask_bpt_pause_report_f() (0x20U)
#define gr_gpc0_tpc0_sm0_hww_global_esr_report_mask_single_step_complete_report_f()\
				(0x40U)
#define gr_gpc0_tpc0_sm0_hww_global_esr_report_mask_error_in_trap_report_f()\
				(0x100U)
#define gr_gpc0_tpc0_sm0_hww_global_esr_report_mask_poison_data_report_f()\
				(0x1000U)
#define gr_gpcs_tpcs_sms_hww_global_esr_r()                        (0x00419eb4U)
#define gr_gpc0_tpc0_sm0_hww_global_esr_r()                        (0x00504734U)
#define gr_gpc0_tpc0_sm0_hww_global_esr_bpt_int_pending_f()              (0x10U)
#define gr_gpc0_tpc0_sm0_hww_global_esr_bpt_pause_pending_f()            (0x20U)
#define gr_gpc0_tpc0_sm0_hww_global_esr_single_step_complete_pending_f() (0x40U)
#define gr_gpc0_tpc0_sm0_hww_global_esr_multiple_warp_errors_pending_f()  (0x4U)
#define gr_fe_go_idle_timeout_r()                                  (0x00404154U)
#define gr_fe_go_idle_timeout_count_disabled_f()                          (0x0U)
#define gr_fe_go_idle_timeout_count_prod_f()                           (0x1800U)
#define gr_fe_compute_go_idle_timeout_r()                          (0x00404160U)
#define gr_fe_compute_go_idle_timeout_count_disabled_f()                  (0x0U)
#define gr_fe_compute_go_idle_timeout_count_init_f()                     (0x40U)
#define gr_fe_object_table_r(i)\
		(nvgpu_safe_add_u32(0x00404200U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_fe_object_table_nvclass_v(r)                  (((r) >> 0U) & 0xffffU)
#define gr_fe_tpc_fs_r(i)\
		(nvgpu_safe_add_u32(0x0040a200U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_pri_mme_shadow_ram_index_r()                            (0x00404488U)
#define gr_pri_mme_shadow_ram_index_nvclass_f(v)      ((U32(v) & 0xffffU) << 0U)
#define gr_pri_mme_shadow_ram_index_nvclass_v(r)         (((r) >> 0U) & 0xffffU)
#define gr_pri_mme_shadow_ram_index_method_address_f(v)\
				((U32(v) & 0xfffU) << 16U)
#define gr_pri_mme_shadow_ram_index_fepipe_f(v)         ((U32(v) & 0x1U) << 29U)
#define gr_pri_mme_shadow_ram_index_fepipe_fe0_f()                        (0x0U)
#define gr_pri_mme_shadow_ram_index_write_trigger_f()              (0x80000000U)
#define gr_pri_mme_shadow_ram_data_r()                             (0x0040448cU)
#define gr_mme_hww_esr_r()                                         (0x00404490U)
#define gr_mme_hww_esr_missing_macro_data_pending_f()                     (0x1U)
#define gr_mme_hww_esr_illegal_opcode_pending_f()                         (0x4U)
#define gr_mme_hww_esr_branch_in_delay_pending_f()                        (0x8U)
#define gr_mme_hww_esr_inst_ram_acess_pending_f()                        (0x20U)
#define gr_mme_hww_esr_data_ram_access_pending_f()                       (0x40U)
#define gr_mme_hww_esr_illegal_mme_method_pending_f()                    (0x80U)
#define gr_mme_hww_esr_dma_dram_access_pending_f()                    (0x10000U)
#define gr_mme_hww_esr_dma_read_pb_pending_f()                        (0x20000U)
#define gr_mme_hww_esr_dma_illegal_fifo_pending_f()                   (0x40000U)
#define gr_mme_hww_esr_dma_read_overflow_pending_f()                  (0x80000U)
#define gr_mme_hww_esr_dma_fifo_resized_pending_f()                  (0x100000U)
#define gr_mme_hww_esr_reset_active_f()                            (0x40000000U)
#define gr_mme_hww_esr_en_enable_f()                               (0x80000000U)
#define gr_mme_hww_esr_info_r()                                    (0x00404494U)
#define gr_mme_hww_esr_info_pc_valid_v(r)                  (((r) >> 28U) & 0x1U)
#define gr_mme_hww_esr_info2_r()                                   (0x0040449cU)
#define gr_mme_hww_esr_info3_r()                                   (0x004044a8U)
#define gr_mme_hww_esr_info4_r()                                   (0x004044acU)
#define gr_memfmt_hww_esr_r()                                      (0x00404600U)
#define gr_memfmt_hww_esr_reset_active_f()                         (0x40000000U)
#define gr_memfmt_hww_esr_en_enable_f()                            (0x80000000U)
#define gr_fecs_cpuctl_r()                                         (0x00409100U)
#define gr_fecs_cpuctl_startcpu_f(v)                     ((U32(v) & 0x1U) << 1U)
#define gr_fecs_cpuctl_alias_r()                                   (0x00409130U)
#define gr_fecs_dmactl_r()                                         (0x0040910cU)
#define gr_fecs_dmactl_require_ctx_f(v)                  ((U32(v) & 0x1U) << 0U)
#define gr_fecs_dmactl_dmem_scrubbing_m()                      (U32(0x1U) << 1U)
#define gr_fecs_dmactl_imem_scrubbing_m()                      (U32(0x1U) << 2U)
#define gr_fecs_mailbox0_r()                                       (0x00409040U)
#define gr_fecs_mailbox1_r()                                       (0x00409044U)
#define gr_fecs_imemc_r(i)\
		(nvgpu_safe_add_u32(0x00409180U, nvgpu_safe_mult_u32((i), 16U)))
#define gr_fecs_imemc_offs_f(v)                         ((U32(v) & 0x3fU) << 2U)
#define gr_fecs_imemc_blk_f(v)                        ((U32(v) & 0xffffU) << 8U)
#define gr_fecs_imemc_aincw_f(v)                        ((U32(v) & 0x1U) << 24U)
#define gr_fecs_imemd_r(i)\
		(nvgpu_safe_add_u32(0x00409184U, nvgpu_safe_mult_u32((i), 16U)))
#define gr_fecs_imemt_r(i)\
		(nvgpu_safe_add_u32(0x00409188U, nvgpu_safe_mult_u32((i), 16U)))
#define gr_fecs_imemt_tag_f(v)                        ((U32(v) & 0xffffU) << 0U)
#define gr_fecs_dmemc_r(i)\
		(nvgpu_safe_add_u32(0x004091c0U, nvgpu_safe_mult_u32((i), 8U)))
#define gr_fecs_dmemc_offs_f(v)                         ((U32(v) & 0x3fU) << 2U)
#define gr_fecs_dmemc_blk_f(v)                        ((U32(v) & 0xffffU) << 8U)
#define gr_fecs_dmemc_aincw_f(v)                        ((U32(v) & 0x1U) << 24U)
#define gr_fecs_dmemd_r(i)\
		(nvgpu_safe_add_u32(0x004091c4U, nvgpu_safe_mult_u32((i), 8U)))
#define gr_fecs_dmatrfbase_r()                                     (0x00409110U)
#define gr_fecs_dmatrfmoffs_r()                                    (0x00409114U)
#define gr_fecs_dmatrffboffs_r()                                   (0x0040911cU)
#define gr_fecs_dmatrfcmd_r()                                      (0x00409118U)
#define gr_fecs_dmatrfcmd_imem_f(v)                      ((U32(v) & 0x1U) << 4U)
#define gr_fecs_dmatrfcmd_write_f(v)                     ((U32(v) & 0x1U) << 5U)
#define gr_fecs_dmatrfcmd_size_f(v)                      ((U32(v) & 0x7U) << 8U)
#define gr_fecs_dmatrfcmd_ctxdma_f(v)                   ((U32(v) & 0x7U) << 12U)
#define gr_fecs_bootvec_r()                                        (0x00409104U)
#define gr_fecs_bootvec_vec_f(v)                  ((U32(v) & 0xffffffffU) << 0U)
#define gr_fecs_irqsset_r()                                        (0x00409000U)
#define gr_fecs_falcon_hwcfg_r()                                   (0x00409108U)
#define gr_gpcs_gpccs_irqsset_r()                                  (0x0041a000U)
#define gr_gpcs_gpccs_falcon_hwcfg_r()                             (0x0041a108U)
#define gr_fecs_current_ctx_r()                                    (0x00409b00U)
#define gr_fecs_current_ctx_ptr_f(v)               ((U32(v) & 0xfffffffU) << 0U)
#define gr_fecs_current_ctx_ptr_v(r)                  (((r) >> 0U) & 0xfffffffU)
#define gr_fecs_current_ctx_target_s()                                      (2U)
#define gr_fecs_current_ctx_target_m()                        (U32(0x3U) << 28U)
#define gr_fecs_current_ctx_target_v(r)                    (((r) >> 28U) & 0x3U)
#define gr_fecs_current_ctx_target_vid_mem_f()                            (0x0U)
#define gr_fecs_current_ctx_target_sys_mem_coh_f()                 (0x20000000U)
#define gr_fecs_current_ctx_target_sys_mem_ncoh_f()                (0x30000000U)
#define gr_fecs_current_ctx_valid_f(v)                  ((U32(v) & 0x1U) << 31U)
#define gr_fecs_current_ctx_valid_m()                         (U32(0x1U) << 31U)
#define gr_fecs_current_ctx_valid_v(r)                     (((r) >> 31U) & 0x1U)
#define gr_fecs_current_ctx_valid_false_f()                               (0x0U)
#define gr_fecs_method_data_r()                                    (0x00409500U)
#define gr_fecs_method_push_r()                                    (0x00409504U)
#define gr_fecs_method_push_adr_f(v)                   ((U32(v) & 0xfffU) << 0U)
#define gr_fecs_method_push_adr_bind_pointer_v()                   (0x00000003U)
#define gr_fecs_method_push_adr_discover_image_size_v()            (0x00000010U)
#define gr_fecs_method_push_adr_wfi_golden_save_v()                (0x00000009U)
#define gr_fecs_method_push_adr_discover_zcull_image_size_v()      (0x00000016U)
#define gr_fecs_method_push_adr_discover_pm_image_size_v()         (0x00000025U)
#define gr_fecs_method_push_adr_discover_reglist_image_size_v()    (0x00000030U)
#define gr_fecs_method_push_adr_set_reglist_bind_instance_v()      (0x00000031U)
#define gr_fecs_method_push_adr_set_reglist_virtual_address_v()    (0x00000032U)
#define gr_fecs_method_push_adr_stop_ctxsw_v()                     (0x00000038U)
#define gr_fecs_method_push_adr_start_ctxsw_v()                    (0x00000039U)
#define gr_fecs_method_push_adr_set_watchdog_timeout_f()                 (0x21U)
#define gr_fecs_method_push_adr_discover_preemption_image_size_v() (0x0000001aU)
#define gr_fecs_method_push_adr_halt_pipeline_v()                  (0x00000004U)
#define gr_fecs_method_push_adr_configure_interrupt_completion_option_v()\
				(0x0000003aU)
#define gr_fecs_method_push_adr_smpc_global_mode_start_v()         (0x00000069U)
#define gr_fecs_method_push_adr_smpc_global_mode_stop_v()          (0x0000006aU)
#define gr_fecs_host_int_status_r()                                (0x00409c18U)
#define gr_fecs_host_int_status_fault_during_ctxsw_f(v) ((U32(v) & 0x1U) << 16U)
#define gr_fecs_host_int_status_umimp_firmware_method_f(v)\
				((U32(v) & 0x1U) << 17U)
#define gr_fecs_host_int_status_watchdog_active_f()                   (0x80000U)
#define gr_fecs_host_int_status_ctxsw_intr_f(v)       ((U32(v) & 0xffffU) << 0U)
#define gr_fecs_host_int_status_ecc_corrected_m()             (U32(0x1U) << 21U)
#define gr_fecs_host_int_status_ecc_uncorrected_m()           (U32(0x1U) << 22U)
#define gr_fecs_host_int_clear_r()                                 (0x00409c20U)
#define gr_fecs_host_int_clear_ctxsw_intr1_clear_f()                      (0x2U)
#define gr_fecs_host_int_enable_r()                                (0x00409c24U)
#define gr_fecs_host_int_enable_ctxsw_intr0_enable_f()                    (0x1U)
#define gr_fecs_host_int_enable_ctxsw_intr1_enable_f()                    (0x2U)
#define gr_fecs_host_int_enable_fault_during_ctxsw_enable_f()         (0x10000U)
#define gr_fecs_host_int_enable_umimp_firmware_method_enable_f()      (0x20000U)
#define gr_fecs_host_int_enable_umimp_illegal_method_enable_f()       (0x40000U)
#define gr_fecs_host_int_enable_watchdog_enable_f()                   (0x80000U)
#define gr_fecs_host_int_enable_flush_when_busy_enable_f()           (0x100000U)
#define gr_fecs_host_int_enable_ecc_corrected_enable_f()             (0x200000U)
#define gr_fecs_host_int_enable_ecc_uncorrected_enable_f()           (0x400000U)
#define gr_fecs_ctxsw_reset_ctl_r()                                (0x00409614U)
#define gr_fecs_ctxsw_reset_ctl_sys_halt_disabled_f()                     (0x0U)
#define gr_fecs_ctxsw_reset_ctl_sys_engine_reset_disabled_f()            (0x10U)
#define gr_fecs_ctxsw_reset_ctl_sys_context_reset_enabled_f()             (0x0U)
#define gr_fecs_ctxsw_reset_ctl_sys_context_reset_disabled_f()          (0x100U)
#define gr_gpccs_ctxsw_reset_ctl_r()                               (0x0041a614U)
#define gr_gpccs_ctxsw_reset_ctl_gpc_halt_disabled_f()                    (0x0U)
#define gr_gpccs_ctxsw_reset_ctl_gpc_reset_disabled_f()                  (0x20U)
#define gr_gpccs_ctxsw_reset_ctl_gpc_context_reset_disabled_f()         (0x200U)
#define gr_gpccs_ctxsw_reset_ctl_gpc_context_reset_enabled_f()            (0x0U)
#define gr_gpccs_ctxsw_reset_ctl_zcull_reset_disabled_f()               (0x800U)
#define gr_gpccs_ctxsw_reset_ctl_zcull_reset_enabled_f()                  (0x0U)
#define gr_bes_becs_ctxsw_be_reset_ctl_r()                         (0x00408a10U)
#define gr_bes_becs_ctxsw_be_reset_ctl_be_halt_disabled_f()               (0x0U)
#define gr_bes_becs_ctxsw_be_reset_ctl_be_engine_reset_disabled_f()      (0x40U)
#define gr_bes_becs_ctxsw_be_reset_ctl_be_context_reset_enabled_f()       (0x0U)
#define gr_bes_becs_ctxsw_be_reset_ctl_be_context_reset_disabled_f()    (0x400U)
#define gr_fecs_ctx_state_store_major_rev_id_r()                   (0x0040960cU)
#define gr_fecs_ctxsw_mailbox_r(i)\
		(nvgpu_safe_add_u32(0x00409800U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_fecs_ctxsw_mailbox__size_1_v()                          (0x00000012U)
#define gr_fecs_ctxsw_mailbox_value_f(v)          ((U32(v) & 0xffffffffU) << 0U)
#define gr_fecs_ctxsw_mailbox_value_pass_v()                       (0x00000001U)
#define gr_fecs_ctxsw_mailbox_value_fail_v()                       (0x00000002U)
#define gr_fecs_ctxsw_mailbox_value_ctxsw_checksum_mismatch_v()    (0x00000021U)
#define gr_fecs_ctxsw_func_tracing_mailbox_r(i)\
		(nvgpu_safe_add_u32(0x004098c0U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_fecs_ctxsw_func_tracing_mailbox__size_1_v()             (0x00000006U)
#define gr_fecs_cfg_r()                                            (0x00409620U)
#define gr_fecs_cfg_imem_sz_v(r)                           (((r) >> 0U) & 0xffU)
#define gr_fecs_ctxsw_status_1_r()                                 (0x00409400U)
#define gr_fecs_ctxsw_status_1_arb_busy_m()                   (U32(0x1U) << 12U)
#define gr_fecs_arb_ctx_adr_r()                                    (0x00409a24U)
#define gr_fecs_new_ctx_r()                                        (0x00409b04U)
#define gr_fecs_new_ctx_ptr_f(v)                   ((U32(v) & 0xfffffffU) << 0U)
#define gr_fecs_new_ctx_target_s()                                          (2U)
#define gr_fecs_new_ctx_target_v(r)                        (((r) >> 28U) & 0x3U)
#define gr_fecs_new_ctx_target_vid_mem_f()                                (0x0U)
#define gr_fecs_new_ctx_target_sys_mem_ncoh_f()                    (0x30000000U)
#define gr_fecs_new_ctx_target_sys_mem_coh_f()                     (0x20000000U)
#define gr_fecs_new_ctx_valid_m()                             (U32(0x1U) << 31U)
#define gr_fecs_arb_ctx_ptr_r()                                    (0x00409a0cU)
#define gr_fecs_arb_ctx_ptr_ptr_f(v)               ((U32(v) & 0xfffffffU) << 0U)
#define gr_fecs_arb_ctx_ptr_target_s()                                      (2U)
#define gr_fecs_arb_ctx_ptr_target_v(r)                    (((r) >> 28U) & 0x3U)
#define gr_fecs_arb_ctx_ptr_target_vid_mem_f()                            (0x0U)
#define gr_fecs_arb_ctx_ptr_target_sys_mem_ncoh_f()                (0x30000000U)
#define gr_fecs_arb_ctx_ptr_target_sys_mem_coh_f()                 (0x20000000U)
#define gr_fecs_arb_ctx_cmd_r()                                    (0x00409a10U)
#define gr_fecs_arb_ctx_cmd_cmd_s()                                         (5U)
#define gr_fecs_arb_ctx_cmd_cmd_v(r)                       (((r) >> 0U) & 0x1fU)
#define gr_fecs_ctxsw_status_fe_0_r()                              (0x00409c00U)
#define gr_gpc0_gpccs_ctxsw_status_gpc_0_r()                       (0x00502c04U)
#define gr_gpc0_gpccs_ctxsw_status_1_r()                           (0x00502400U)
#define gr_fecs_ctxsw_idlestate_r()                                (0x00409420U)
#define gr_gpc0_gpccs_ctxsw_idlestate_r()                          (0x00502420U)
#define gr_rstr2d_gpc_map_r(i)\
		(nvgpu_safe_add_u32(0x0040780cU, nvgpu_safe_mult_u32((i), 4U)))
#define gr_rstr2d_map_table_cfg_r()                                (0x004078bcU)
#define gr_rstr2d_map_table_cfg_row_offset_f(v)         ((U32(v) & 0xffU) << 0U)
#define gr_rstr2d_map_table_cfg_num_entries_f(v)        ((U32(v) & 0xffU) << 8U)
#define gr_pd_hww_esr_r()                                          (0x00406018U)
#define gr_pd_hww_esr_reset_active_f()                             (0x40000000U)
#define gr_pd_hww_esr_en_enable_f()                                (0x80000000U)
#define gr_pd_num_tpc_per_gpc_r(i)\
		(nvgpu_safe_add_u32(0x00406028U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_pd_num_tpc_per_gpc__size_1_v()                          (0x00000004U)
#define gr_pd_num_tpc_per_gpc_count0_f(v)                ((U32(v) & 0xfU) << 0U)
#define gr_pd_num_tpc_per_gpc_count1_f(v)                ((U32(v) & 0xfU) << 4U)
#define gr_pd_num_tpc_per_gpc_count2_f(v)                ((U32(v) & 0xfU) << 8U)
#define gr_pd_num_tpc_per_gpc_count3_f(v)               ((U32(v) & 0xfU) << 12U)
#define gr_pd_num_tpc_per_gpc_count4_f(v)               ((U32(v) & 0xfU) << 16U)
#define gr_pd_num_tpc_per_gpc_count5_f(v)               ((U32(v) & 0xfU) << 20U)
#define gr_pd_num_tpc_per_gpc_count6_f(v)               ((U32(v) & 0xfU) << 24U)
#define gr_pd_num_tpc_per_gpc_count7_f(v)               ((U32(v) & 0xfU) << 28U)
#define gr_pd_ab_dist_cfg0_r()                                     (0x004064c0U)
#define gr_pd_ab_dist_cfg0_timeslice_enable_en_f()                 (0x80000000U)
#define gr_pd_ab_dist_cfg1_r()                                     (0x004064c4U)
#define gr_pd_ab_dist_cfg1_max_batches_init_f()                        (0xffffU)
#define gr_pd_ab_dist_cfg1_max_output_f(v)           ((U32(v) & 0xffffU) << 16U)
#define gr_pd_ab_dist_cfg1_max_output_granularity_v()              (0x00000080U)
#define gr_pd_ab_dist_cfg2_r()                                     (0x004064c8U)
#define gr_pd_ab_dist_cfg2_token_limit_f(v)           ((U32(v) & 0x3fffU) << 0U)
#define gr_pd_ab_dist_cfg2_token_limit_init_v()                    (0x00002180U)
#define gr_pd_ab_dist_cfg2_state_limit_f(v)          ((U32(v) & 0x3fffU) << 16U)
#define gr_pd_ab_dist_cfg2_state_limit_scc_bundle_granularity_v()  (0x00000020U)
#define gr_pd_ab_dist_cfg2_state_limit_min_gpm_fifo_depths_v()     (0x00002180U)
#define gr_pd_dist_skip_table_r(i)\
		(nvgpu_safe_add_u32(0x004064d0U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_pd_dist_skip_table__size_1_v()                          (0x00000008U)
#define gr_pd_dist_skip_table_gpc_4n0_mask_f(v)         ((U32(v) & 0xffU) << 0U)
#define gr_pd_dist_skip_table_gpc_4n1_mask_f(v)         ((U32(v) & 0xffU) << 8U)
#define gr_pd_dist_skip_table_gpc_4n2_mask_f(v)        ((U32(v) & 0xffU) << 16U)
#define gr_pd_dist_skip_table_gpc_4n3_mask_f(v)        ((U32(v) & 0xffU) << 24U)
#define gr_ds_debug_r()                                            (0x00405800U)
#define gr_ds_tga_constraintlogic_beta_r()                         (0x00405830U)
#define gr_ds_tga_constraintlogic_beta_cbsize_f(v)  ((U32(v) & 0x3fffffU) << 0U)
#define gr_ds_tga_constraintlogic_alpha_r()                        (0x0040585cU)
#define gr_ds_tga_constraintlogic_alpha_cbsize_f(v)   ((U32(v) & 0xffffU) << 0U)
#define gr_ds_hww_esr_r()                                          (0x00405840U)
#define gr_ds_hww_esr_reset_task_f()                               (0x40000000U)
#define gr_ds_hww_esr_en_enabled_f()                               (0x80000000U)
#define gr_ds_num_tpc_per_gpc_r(i)\
		(nvgpu_safe_add_u32(0x00405870U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_scc_debug_r()                                           (0x00408000U)
#define gr_scc_debug_pagepool_invalidates_m()                  (U32(0x1U) << 9U)
#define gr_scc_debug_pagepool_invalidates_disable_f()                   (0x200U)
#define gr_scc_bundle_cb_base_r()                                  (0x00408004U)
#define gr_scc_bundle_cb_base_addr_39_8_f(v)      ((U32(v) & 0xffffffffU) << 0U)
#define gr_scc_bundle_cb_base_addr_39_8_align_bits_v()             (0x00000008U)
#define gr_scc_bundle_cb_size_r()                                  (0x00408008U)
#define gr_scc_bundle_cb_size_div_256b_f(v)            ((U32(v) & 0x7ffU) << 0U)
#define gr_scc_bundle_cb_size_div_256b__prod_v()                   (0x00000030U)
#define gr_scc_bundle_cb_size_div_256b_byte_granularity_v()        (0x00000100U)
#define gr_scc_bundle_cb_size_valid_true_f()                       (0x80000000U)
#define gr_scc_pagepool_base_r()                                   (0x0040800cU)
#define gr_scc_pagepool_base_addr_39_8_f(v)       ((U32(v) & 0xffffffffU) << 0U)
#define gr_scc_pagepool_base_addr_39_8_align_bits_v()              (0x00000008U)
#define gr_scc_pagepool_r()                                        (0x00408010U)
#define gr_scc_pagepool_total_pages_f(v)               ((U32(v) & 0x3ffU) << 0U)
#define gr_scc_pagepool_total_pages_hwmax_v()                      (0x00000000U)
#define gr_scc_pagepool_total_pages_hwmax_value_v()                (0x00000200U)
#define gr_scc_pagepool_total_pages_byte_granularity_v()           (0x00000100U)
#define gr_scc_pagepool_valid_true_f()                             (0x80000000U)
#define gr_scc_rm_rtv_cb_base_r()                                  (0x00408070U)
#define gr_scc_rm_rtv_cb_base_addr_39_8_f(v)      ((U32(v) & 0xffffffffU) << 0U)
#define gr_scc_rm_rtv_cb_base_addr_39_8_align_bits_f()                    (0x8U)
#define gr_scc_rm_rtv_cb_size_r()                                  (0x00408074U)
#define gr_scc_rm_rtv_cb_size_div_256b_f(v)           ((U32(v) & 0x7fffU) << 0U)
#define gr_scc_rm_rtv_cb_size_div_256b_byte_granularity_v()        (0x00000100U)
#define gr_scc_rm_rtv_cb_size_div_256b_default_f()                      (0x800U)
#define gr_scc_rm_rtv_cb_size_div_256b_db_adder_f()                       (0x0U)
#define gr_scc_rm_rtv_cb_size_div_256b_gfxp_adder_f()                    (0x20U)
#define gr_gpcs_gcc_rm_rtv_cb_base_r()                             (0x00419034U)
#define gr_gpcs_gcc_rm_rtv_cb_base_addr_39_8_f(v) ((U32(v) & 0xffffffffU) << 0U)
#define gr_scc_rm_gfxp_reserve_r()                                 (0x00408078U)
#define gr_scc_rm_gfxp_reserve_rtv_cb_size_div_256b_f(v)\
				((U32(v) & 0x1ffU) << 0U)
#define gr_scc_hww_esr_r()                                         (0x00408030U)
#define gr_scc_hww_esr_reset_active_f()                            (0x40000000U)
#define gr_scc_hww_esr_en_enable_f()                               (0x80000000U)
#define gr_ssync_hww_esr_r()                                       (0x00405a14U)
#define gr_ssync_hww_esr_reset_active_f()                          (0x40000000U)
#define gr_ssync_hww_esr_en_enable_f()                             (0x80000000U)
#define gr_sked_hww_esr_r()                                        (0x00407020U)
#define gr_sked_hww_esr_reset_active_f()                           (0x40000000U)
#define gr_sked_hww_esr_en_r()                                     (0x00407024U)
#define gr_sked_hww_esr_en_skedcheck18_l1_config_too_small_m()\
				(U32(0x1U) << 25U)
#define gr_sked_hww_esr_en_skedcheck18_l1_config_too_small_disabled_f()   (0x0U)
#define gr_sked_hww_esr_en_skedcheck18_l1_config_too_small_enabled_f()\
				(0x2000000U)
#define gr_cwd_fs_r()                                              (0x00405b00U)
#define gr_cwd_fs_num_gpcs_f(v)                         ((U32(v) & 0xffU) << 0U)
#define gr_cwd_fs_num_tpcs_f(v)                         ((U32(v) & 0xffU) << 8U)
#define gr_cwd_gpc_tpc_id_r(i)\
		(nvgpu_safe_add_u32(0x00405b60U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_cwd_gpc_tpc_id_tpc0_s()                                          (4U)
#define gr_cwd_gpc_tpc_id_tpc0_f(v)                      ((U32(v) & 0xfU) << 0U)
#define gr_cwd_gpc_tpc_id_gpc0_s()                                          (4U)
#define gr_cwd_gpc_tpc_id_gpc0_f(v)                      ((U32(v) & 0xfU) << 4U)
#define gr_cwd_sm_id_r(i)\
		(nvgpu_safe_add_u32(0x00405ba0U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_cwd_sm_id__size_1_v()                                   (0x00000010U)
#define gr_gpc0_fs_gpc_r()                                         (0x00502608U)
#define gr_gpc0_fs_gpc_num_available_tpcs_v(r)             (((r) >> 0U) & 0x1fU)
#define gr_gpc0_fs_gpc_num_available_zculls_v(r)          (((r) >> 16U) & 0x1fU)
#define gr_gpc0_cfg_r()                                            (0x00502620U)
#define gr_gpc0_cfg_imem_sz_v(r)                           (((r) >> 0U) & 0xffU)
#define gr_gpc0_zcull_fs_r()                                       (0x00500910U)
#define gr_gpc0_zcull_fs_num_sms_f(v)                  ((U32(v) & 0x1ffU) << 0U)
#define gr_gpc0_zcull_fs_num_active_banks_f(v)          ((U32(v) & 0xfU) << 16U)
#define gr_gpc0_zcull_ram_addr_r()                                 (0x00500914U)
#define gr_gpc0_zcull_ram_addr_tiles_per_hypertile_row_per_gpc_f(v)\
				((U32(v) & 0xfU) << 0U)
#define gr_gpc0_zcull_ram_addr_row_offset_f(v)           ((U32(v) & 0xfU) << 8U)
#define gr_gpc0_zcull_sm_num_rcp_r()                               (0x00500918U)
#define gr_gpc0_zcull_sm_num_rcp_conservative_f(v)  ((U32(v) & 0xffffffU) << 0U)
#define gr_gpc0_zcull_sm_num_rcp_conservative__max_v()             (0x00800000U)
#define gr_gpc0_zcull_total_ram_size_r()                           (0x00500920U)
#define gr_gpc0_zcull_total_ram_size_num_aliquots_f(v)\
				((U32(v) & 0xffffU) << 0U)
#define gr_gpc0_zcull_zcsize_r(i)\
		(nvgpu_safe_add_u32(0x00500a04U, nvgpu_safe_mult_u32((i), 32U)))
#define gr_gpc0_zcull_zcsize_height_subregion__multiple_v()        (0x00000040U)
#define gr_gpc0_zcull_zcsize_width_subregion__multiple_v()         (0x00000010U)
#define gr_gpc0_gpm_pd_sm_id_r(i)\
		(nvgpu_safe_add_u32(0x00500c10U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_gpc0_gpm_pd_sm_id_id_f(v)                    ((U32(v) & 0xffU) << 0U)
#define gr_gpc0_gpm_pd_pes_tpc_id_mask_r(i)\
		(nvgpu_safe_add_u32(0x00500c30U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_gpc0_gpm_pd_pes_tpc_id_mask_mask_v(r)           (((r) >> 0U) & 0xffU)
#define gr_gpc0_tpc0_sm_cfg_r()                                    (0x00504608U)
#define gr_gpc0_tpc0_sm_cfg_tpc_id_f(v)               ((U32(v) & 0xffffU) << 0U)
#define gr_gpc0_tpc0_sm_arch_r()                                   (0x00504330U)
#define gr_gpc0_tpc0_sm_arch_warp_count_v(r)               (((r) >> 0U) & 0xffU)
#define gr_gpc0_tpc0_sm_arch_spa_version_v(r)             (((r) >> 8U) & 0xfffU)
#define gr_gpc0_tpc0_sm_arch_sm_version_v(r)             (((r) >> 20U) & 0xfffU)
#define gr_gpc0_ppc0_pes_vsc_strem_r()                             (0x00503018U)
#define gr_gpc0_ppc0_pes_vsc_strem_master_pe_m()               (U32(0x1U) << 0U)
#define gr_gpc0_ppc0_pes_vsc_strem_master_pe_true_f()                     (0x1U)
#define gr_gpc0_ppc0_cbm_beta_cb_size_r()                          (0x005030c0U)
#define gr_gpc0_ppc0_cbm_beta_cb_size_v_f(v)        ((U32(v) & 0x3fffffU) << 0U)
#define gr_gpc0_ppc0_cbm_beta_cb_size_v_m()               (U32(0x3fffffU) << 0U)
#define gr_gpc0_ppc0_cbm_beta_cb_size_v_default_v()                (0x00001800U)
#define gr_gpc0_ppc0_cbm_beta_cb_size_v_gfxp_v()                   (0x00002080U)
#define gr_gpc0_ppc0_cbm_beta_cb_size_v_granularity_v()            (0x00000020U)
#define gr_gpc0_ppc0_cbm_beta_cb_offset_r()                        (0x005030f4U)
#define gr_gpc0_ppc0_cbm_alpha_cb_size_r()                         (0x005030e4U)
#define gr_gpc0_ppc0_cbm_alpha_cb_size_v_f(v)         ((U32(v) & 0xffffU) << 0U)
#define gr_gpc0_ppc0_cbm_alpha_cb_size_v_m()                (U32(0xffffU) << 0U)
#define gr_gpc0_ppc0_cbm_alpha_cb_size_v_default_v()               (0x00000800U)
#define gr_gpc0_ppc0_cbm_alpha_cb_size_v_granularity_v()           (0x00000020U)
#define gr_gpc0_ppc0_cbm_alpha_cb_offset_r()                       (0x005030f8U)
#define gr_gpc0_swdx_pes_mask_r()                                  (0x005001d0U)
#define gr_gpc0_gpm_pd_live_physical_pes_r()                       (0x00500c50U)
#define gr_gpc0_gpm_pd_live_physical_pes_gpc0_gpm_pd_live_physical_pes_mask_f(v)\
				((U32(v) & 0xfU) << 0U)
#define gr_gpcs_tpcs_tex_m_dbg2_r()                                (0x00419a3cU)
#define gr_gpc0_ppc0_cbm_beta_steady_state_cb_size_r()             (0x005030f0U)
#define gr_gpc0_ppc0_cbm_beta_steady_state_cb_size_v_f(v)\
				((U32(v) & 0x3fffffU) << 0U)
#define gr_gpcs_tpcs_tex_rm_cb_0_r()                               (0x00419e00U)
#define gr_gpcs_tpcs_tex_rm_cb_0_base_addr_43_12_f(v)\
				((U32(v) & 0xffffffffU) << 0U)
#define gr_gpcs_tpcs_tex_rm_cb_1_r()                               (0x00419e04U)
#define gr_gpcs_tpcs_tex_rm_cb_1_size_div_128b_f(v) ((U32(v) & 0x1fffffU) << 0U)
#define gr_gpcs_tpcs_tex_rm_cb_1_size_div_128b_granularity_f()           (0x80U)
#define gr_gpcs_tpcs_tex_rm_cb_1_valid_true_f()                    (0x80000000U)
#define gr_gpccs_cpuctl_r()                                        (0x0041a100U)
#define gr_gpccs_cpuctl_startcpu_f(v)                    ((U32(v) & 0x1U) << 1U)
#define gr_gpccs_dmactl_r()                                        (0x0041a10cU)
#define gr_gpccs_dmactl_require_ctx_f(v)                 ((U32(v) & 0x1U) << 0U)
#define gr_gpccs_dmactl_imem_scrubbing_m()                     (U32(0x1U) << 2U)
#define gr_gpccs_imemc_r(i)\
		(nvgpu_safe_add_u32(0x0041a180U, nvgpu_safe_mult_u32((i), 16U)))
#define gr_gpccs_imemc_offs_f(v)                        ((U32(v) & 0x3fU) << 2U)
#define gr_gpccs_imemc_blk_f(v)                       ((U32(v) & 0xffffU) << 8U)
#define gr_gpccs_imemc_aincw_f(v)                       ((U32(v) & 0x1U) << 24U)
#define gr_gpccs_imemd_r(i)\
		(nvgpu_safe_add_u32(0x0041a184U, nvgpu_safe_mult_u32((i), 16U)))
#define gr_gpccs_imemt_r(i)\
		(nvgpu_safe_add_u32(0x0041a188U, nvgpu_safe_mult_u32((i), 16U)))
#define gr_gpccs_imemt_tag_f(v)                       ((U32(v) & 0xffffU) << 0U)
#define gr_gpccs_dmemc_r(i)\
		(nvgpu_safe_add_u32(0x0041a1c0U, nvgpu_safe_mult_u32((i), 8U)))
#define gr_gpccs_dmemc_offs_f(v)                        ((U32(v) & 0x3fU) << 2U)
#define gr_gpccs_dmemc_blk_f(v)                       ((U32(v) & 0xffffU) << 8U)
#define gr_gpccs_dmemc_aincw_f(v)                       ((U32(v) & 0x1U) << 24U)
#define gr_gpccs_dmemd_r(i)\
		(nvgpu_safe_add_u32(0x0041a1c4U, nvgpu_safe_mult_u32((i), 8U)))
#define gr_gpccs_ctxsw_mailbox_r(i)\
		(nvgpu_safe_add_u32(0x0041a800U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_gpccs_ctxsw_mailbox__size_1_v()                         (0x00000012U)
#define gr_gpccs_ctxsw_mailbox_value_f(v)         ((U32(v) & 0xffffffffU) << 0U)
#define gr_gpc0_gpccs_ctxsw_mailbox_r(i)\
		(nvgpu_safe_add_u32(0x00502800U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_gpc0_gpccs_ctxsw_func_tracing_mailbox_r(i)\
		(nvgpu_safe_add_u32(0x005028c0U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_gpc0_gpccs_ctxsw_func_tracing_mailbox__size_1_v()       (0x00000006U)
#define gr_gpcs_swdx_bundle_cb_base_r()                            (0x00418e24U)
#define gr_gpcs_swdx_bundle_cb_base_addr_39_8_f(v)\
				((U32(v) & 0xffffffffU) << 0U)
#define gr_gpcs_swdx_bundle_cb_size_r()                            (0x00418e28U)
#define gr_gpcs_swdx_bundle_cb_size_div_256b_f(v)      ((U32(v) & 0x7ffU) << 0U)
#define gr_gpcs_swdx_bundle_cb_size_valid_true_f()                 (0x80000000U)
#define gr_gpc0_swdx_rm_spill_buffer_size_r()                      (0x005001dcU)
#define gr_gpc0_swdx_rm_spill_buffer_size_256b_f(v)   ((U32(v) & 0xffffU) << 0U)
#define gr_gpc0_swdx_rm_spill_buffer_size_256b_default_v()         (0x000004e0U)
#define gr_gpc0_swdx_rm_spill_buffer_size_256b_byte_granularity_v()\
				(0x00000100U)
#define gr_gpc0_swdx_rm_spill_buffer_addr_r()                      (0x005001d8U)
#define gr_gpc0_swdx_rm_spill_buffer_addr_39_8_f(v)\
				((U32(v) & 0xffffffffU) << 0U)
#define gr_gpc0_swdx_rm_spill_buffer_addr_39_8_align_bits_v()      (0x00000008U)
#define gr_gpcs_swdx_beta_cb_ctrl_r()                              (0x004181e4U)
#define gr_gpcs_swdx_beta_cb_ctrl_cbes_reserve_f(v)    ((U32(v) & 0xfffU) << 0U)
#define gr_gpcs_swdx_beta_cb_ctrl_cbes_reserve_gfxp_v()            (0x00000100U)
#define gr_gpcs_ppcs_cbm_beta_cb_ctrl_r()                          (0x0041befcU)
#define gr_gpcs_ppcs_cbm_beta_cb_ctrl_cbes_reserve_f(v)\
				((U32(v) & 0xfffU) << 0U)
#define gr_gpcs_ppcs_cbm_debug_r()                                 (0x0041bec4U)
#define gr_gpcs_ppcs_cbm_debug_invalidate_alpha_m()            (U32(0x1U) << 0U)
#define gr_gpcs_ppcs_cbm_debug_invalidate_alpha_disable_f()               (0x0U)
#define gr_gpcs_ppcs_cbm_debug_invalidate_beta_m()             (U32(0x1U) << 1U)
#define gr_gpcs_ppcs_cbm_debug_invalidate_beta_disable_f()                (0x0U)
#define gr_gpcs_swdx_tc_beta_cb_size_r(i)\
		(nvgpu_safe_add_u32(0x00418ea0U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_gpcs_swdx_tc_beta_cb_size_v_f(v)         ((U32(v) & 0x3fffffU) << 0U)
#define gr_gpcs_swdx_tc_beta_cb_size_v_m()                (U32(0x3fffffU) << 0U)
#define gr_gpcs_swdx_dss_zbc_color_r_r(i)\
		(nvgpu_safe_add_u32(0x00418010U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_gpcs_swdx_dss_zbc_color_r__size_1_v()                   (0x0000000fU)
#define gr_gpcs_swdx_dss_zbc_color_g_r(i)\
		(nvgpu_safe_add_u32(0x0041804cU, nvgpu_safe_mult_u32((i), 4U)))
#define gr_gpcs_swdx_dss_zbc_color_b_r(i)\
		(nvgpu_safe_add_u32(0x00418088U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_gpcs_swdx_dss_zbc_color_a_r(i)\
		(nvgpu_safe_add_u32(0x004180c4U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_gpcs_swdx_dss_zbc_c_01_to_04_format_r()                 (0x00418100U)
#define gr_gpcs_swdx_dss_zbc_z_r(i)\
		(nvgpu_safe_add_u32(0x00418110U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_gpcs_swdx_dss_zbc_z__size_1_v()                         (0x0000000fU)
#define gr_gpcs_swdx_dss_zbc_z_01_to_04_format_r()                 (0x0041814cU)
#define gr_gpcs_swdx_dss_zbc_s_r(i)\
		(nvgpu_safe_add_u32(0x0041815cU, nvgpu_safe_mult_u32((i), 4U)))
#define gr_gpcs_swdx_dss_zbc_s__size_1_v()                         (0x0000000fU)
#define gr_gpcs_swdx_dss_zbc_s_01_to_04_format_r()                 (0x00418198U)
#define gr_gpcs_swdx_spill_unit_r()                                (0x00418e9cU)
#define gr_gpcs_swdx_spill_unit_spill_buffer_cache_mgmt_mode_m()\
				(U32(0x1U) << 16U)
#define gr_gpcs_swdx_spill_unit_spill_buffer_cache_mgmt_mode_disabled_f() (0x0U)
#define gr_gpcs_setup_attrib_cb_base_r()                           (0x00418810U)
#define gr_gpcs_setup_attrib_cb_base_addr_39_12_f(v)\
				((U32(v) & 0xfffffffU) << 0U)
#define gr_gpcs_setup_attrib_cb_base_addr_39_12_align_bits_v()     (0x0000000cU)
#define gr_gpcs_setup_attrib_cb_base_valid_true_f()                (0x80000000U)
#define gr_crstr_gpc_map_r(i)\
		(nvgpu_safe_add_u32(0x00418b08U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_crstr_gpc_map_tile0_f(v)                     ((U32(v) & 0x1fU) << 0U)
#define gr_crstr_gpc_map_tile1_f(v)                     ((U32(v) & 0x1fU) << 5U)
#define gr_crstr_gpc_map_tile2_f(v)                    ((U32(v) & 0x1fU) << 10U)
#define gr_crstr_gpc_map_tile3_f(v)                    ((U32(v) & 0x1fU) << 15U)
#define gr_crstr_gpc_map_tile4_f(v)                    ((U32(v) & 0x1fU) << 20U)
#define gr_crstr_gpc_map_tile5_f(v)                    ((U32(v) & 0x1fU) << 25U)
#define gr_crstr_map_table_cfg_r()                                 (0x00418bb8U)
#define gr_crstr_map_table_cfg_row_offset_f(v)          ((U32(v) & 0xffU) << 0U)
#define gr_crstr_map_table_cfg_num_entries_f(v)         ((U32(v) & 0xffU) << 8U)
#define gr_gpcs_zcull_sm_in_gpc_number_map_r(i)\
		(nvgpu_safe_add_u32(0x00418980U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_gpcs_zcull_sm_in_gpc_number_map_tile_0_f(v)   ((U32(v) & 0x7U) << 0U)
#define gr_gpcs_zcull_sm_in_gpc_number_map_tile_1_f(v)   ((U32(v) & 0x7U) << 4U)
#define gr_gpcs_zcull_sm_in_gpc_number_map_tile_2_f(v)   ((U32(v) & 0x7U) << 8U)
#define gr_gpcs_zcull_sm_in_gpc_number_map_tile_3_f(v)  ((U32(v) & 0x7U) << 12U)
#define gr_gpcs_zcull_sm_in_gpc_number_map_tile_4_f(v)  ((U32(v) & 0x7U) << 16U)
#define gr_gpcs_zcull_sm_in_gpc_number_map_tile_5_f(v)  ((U32(v) & 0x7U) << 20U)
#define gr_gpcs_zcull_sm_in_gpc_number_map_tile_6_f(v)  ((U32(v) & 0x7U) << 24U)
#define gr_gpcs_zcull_sm_in_gpc_number_map_tile_7_f(v)  ((U32(v) & 0x7U) << 28U)
#define gr_gpcs_gpm_pd_cfg_r()                                     (0x00418c6cU)
#define gr_gpcs_gcc_pagepool_base_r()                              (0x00419004U)
#define gr_gpcs_gcc_pagepool_base_addr_39_8_f(v)  ((U32(v) & 0xffffffffU) << 0U)
#define gr_gpcs_gcc_pagepool_r()                                   (0x00419008U)
#define gr_gpcs_gcc_pagepool_total_pages_f(v)          ((U32(v) & 0x3ffU) << 0U)
#define gr_gpcs_tpcs_pe_vaf_r()                                    (0x0041980cU)
#define gr_gpcs_tpcs_pe_vaf_fast_mode_switch_true_f()                    (0x10U)
#define gr_gpcs_tpcs_mpc_pix_debug_r()                             (0x00419c04U)
#define gr_gpcs_tpcs_mpc_pix_debug_cta_subpartition_skew_m()  (U32(0x1U) << 13U)
#define gr_gpcs_tpcs_mpc_pix_debug_cta_subpartition_skew_disable_f()      (0x0U)
#define gr_gpcs_tpcs_pe_pin_cb_global_base_addr_r()                (0x00419848U)
#define gr_gpcs_tpcs_pe_pin_cb_global_base_addr_v_f(v)\
				((U32(v) & 0xfffffffU) << 0U)
#define gr_gpcs_tpcs_pe_pin_cb_global_base_addr_valid_true_f()     (0x10000000U)
#define gr_gpcs_tpcs_mpc_vtg_cb_global_base_addr_r()               (0x00419c2cU)
#define gr_gpcs_tpcs_mpc_vtg_cb_global_base_addr_v_f(v)\
				((U32(v) & 0xfffffffU) << 0U)
#define gr_gpcs_tpcs_mpc_vtg_cb_global_base_addr_valid_true_f()    (0x10000000U)
#define gr_gpcs_tpcs_sms_hww_warp_esr_report_mask_r()              (0x00419ea8U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_report_mask_r()              (0x00504728U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_report_mask_api_stack_error_report_f()\
				(0x4U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_report_mask_misaligned_pc_report_f()\
				(0x20U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_report_mask_pc_overflow_report_f() (0x40U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_report_mask_misaligned_reg_report_f()\
				(0x100U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_report_mask_illegal_instr_encoding_report_f()\
				(0x200U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_report_mask_illegal_instr_param_report_f()\
				(0x800U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_report_mask_oor_reg_report_f()   (0x2000U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_report_mask_oor_addr_report_f()  (0x4000U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_report_mask_misaligned_addr_report_f()\
				(0x8000U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_report_mask_invalid_addr_space_report_f()\
				(0x10000U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_report_mask_invalid_const_addr_ldc_report_f()\
				(0x40000U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_report_mask_mmu_fault_report_f()\
				(0x800000U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_report_mask_tex_format_report_f()\
				(0x1000000U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_report_mask_tex_layout_report_f()\
				(0x2000000U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_report_mask_mmu_nack_report_f()\
				(0x4000000U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_report_mask_arrive_report_f() (0x8000000U)
#define gr_gpcs_tpcs_tpccs_tpc_exception_en_r()                    (0x00419d0cU)
#define gr_gpcs_tpcs_tpccs_tpc_exception_en_sm_enabled_f()                (0x2U)
#define gr_gpcs_tpcs_tpccs_tpc_exception_en_mpc_enabled_f()              (0x10U)
#define gr_gpcs_tpcs_tpccs_tpc_exception_en_pe_enabled_f()                (0x4U)
#define gr_gpc0_tpc0_tpccs_tpc_exception_en_r()                    (0x0050450cU)
#define gr_gpc0_tpc0_tpccs_tpc_exception_en_sm_v(r)         (((r) >> 1U) & 0x1U)
#define gr_gpc0_tpc0_tpccs_tpc_exception_en_sm_enabled_f()                (0x2U)
#define gr_gpcs_gpccs_gpc_exception_en_r()                         (0x0041ac94U)
#define gr_gpcs_gpccs_gpc_exception_en_gcc_enabled_f()                    (0x4U)
#define gr_gpcs_gpccs_gpc_exception_en_tpc_f(v)        ((U32(v) & 0xffU) << 16U)
#define gr_gpcs_gpccs_gpc_exception_en_gpccs_enabled_f()               (0x4000U)
#define gr_gpcs_gpccs_gpc_exception_en_gpcmmu0_enabled_f()             (0x2000U)
#define gr_gpc0_gpccs_gpc_exception_r()                            (0x00502c90U)
#define gr_gpc0_gpccs_gpc_exception_prop_m()                   (U32(0x1U) << 0U)
#define gr_gpc0_gpccs_gpc_exception_zcull_m()                  (U32(0x1U) << 1U)
#define gr_gpc0_gpccs_gpc_exception_setup_m()                  (U32(0x1U) << 3U)
#define gr_gpc0_gpccs_gpc_exception_pes0_m()                   (U32(0x1U) << 4U)
#define gr_gpc0_gpccs_gpc_exception_pes1_m()                   (U32(0x1U) << 5U)
#define gr_gpc0_gpccs_gpc_exception_gcc_v(r)                (((r) >> 2U) & 0x1U)
#define gr_gpc0_gpccs_gpc_exception_tpc_v(r)              (((r) >> 16U) & 0xffU)
#define gr_gpc0_gpccs_gpc_exception_gpccs_m()                 (U32(0x1U) << 14U)
#define gr_gpc0_gpccs_gpc_exception_gpcmmu0_m()               (U32(0x1U) << 13U)
#define gr_pri_gpc0_gcc_l15_ecc_control_r()                        (0x00501044U)
#define gr_pri_gpc0_gcc_l15_ecc_control_inject_uncorrected_err_f(v)\
				((U32(v) & 0x1U) << 1U)
#define gr_gpc0_tpc0_tpccs_tpc_exception_r()                       (0x00504508U)
#define gr_gpc0_tpc0_tpccs_tpc_exception_sm_v(r)            (((r) >> 1U) & 0x1U)
#define gr_gpc0_tpc0_tpccs_tpc_exception_sm_pending_v()            (0x00000001U)
#define gr_gpc0_tpc0_tpccs_tpc_exception_mpc_m()               (U32(0x1U) << 4U)
#define gr_gpc0_tpc0_tpccs_tpc_exception_pe_m()                (U32(0x1U) << 2U)
#define gr_gpc0_tpc0_sm0_dbgr_control0_r()                         (0x00504704U)
#define gr_gpc0_tpc0_sm0_dbgr_control0_debugger_mode_m()       (U32(0x1U) << 0U)
#define gr_gpc0_tpc0_sm0_dbgr_control0_debugger_mode_v(r)   (((r) >> 0U) & 0x1U)
#define gr_gpc0_tpc0_sm0_dbgr_control0_debugger_mode_on_v()        (0x00000001U)
#define gr_gpc0_tpc0_sm0_dbgr_control0_debugger_mode_on_f()               (0x1U)
#define gr_gpc0_tpc0_sm0_dbgr_control0_debugger_mode_off_f()              (0x0U)
#define gr_gpc0_tpc0_sm0_dbgr_control0_stop_trigger_m()       (U32(0x1U) << 31U)
#define gr_gpc0_tpc0_sm0_dbgr_control0_stop_trigger_enable_f()     (0x80000000U)
#define gr_gpc0_tpc0_sm0_dbgr_control0_stop_trigger_disable_f()           (0x0U)
#define gr_gpc0_tpc0_sm0_dbgr_control0_single_step_mode_m()    (U32(0x1U) << 3U)
#define gr_gpc0_tpc0_sm0_dbgr_control0_single_step_mode_enable_f()        (0x8U)
#define gr_gpc0_tpc0_sm0_dbgr_control0_single_step_mode_disable_f()       (0x0U)
#define gr_gpc0_tpc0_sm0_dbgr_control0_run_trigger_task_f()        (0x40000000U)
#define gr_gpc0_tpc0_sm0_warp_valid_mask_0_r()                     (0x00504708U)
#define gr_gpc0_tpc0_sm0_warp_valid_mask_1_r()                     (0x0050470cU)
#define gr_gpc0_tpc0_sm0_dbgr_bpt_pause_mask_0_r()                 (0x00504710U)
#define gr_gpc0_tpc0_sm0_dbgr_bpt_pause_mask_1_r()                 (0x00504714U)
#define gr_gpc0_tpc0_sm0_dbgr_bpt_trap_mask_0_r()                  (0x00504718U)
#define gr_gpc0_tpc0_sm0_dbgr_bpt_trap_mask_1_r()                  (0x0050471cU)
#define gr_gpcs_tpcs_sms_dbgr_bpt_pause_mask_0_r()                 (0x00419e90U)
#define gr_gpcs_tpcs_sms_dbgr_bpt_pause_mask_1_r()                 (0x00419e94U)
#define gr_gpcs_tpcs_sms_dbgr_status0_r()                          (0x00419e80U)
#define gr_gpc0_tpc0_sm0_dbgr_status0_r()                          (0x00504700U)
#define gr_gpc0_tpc0_sm0_dbgr_status0_locked_down_v(r)      (((r) >> 4U) & 0x1U)
#define gr_gpc0_tpc0_sm0_dbgr_status0_locked_down_true_v()         (0x00000001U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_r()                          (0x00504730U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_error_v(r)         (((r) >> 0U) & 0xffffU)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_error_none_v()               (0x00000000U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_error_api_stack_error_f()           (0x2U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_error_misaligned_pc_f()             (0x5U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_error_pc_overflow_f()               (0x6U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_error_misaligned_reg_f()            (0x8U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_error_illegal_instr_encoding_f()    (0x9U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_error_illegal_instr_param_f()       (0xbU)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_error_oor_reg_f()                   (0xdU)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_error_oor_addr_f()                  (0xeU)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_error_misaligned_addr_f()           (0xfU)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_error_invalid_addr_space_f()       (0x10U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_error_invalid_const_addr_ldc_f()   (0x12U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_error_mmu_fault_f()                (0x17U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_error_tex_format_f()               (0x18U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_error_tex_layout_f()               (0x19U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_error_mmu_nack_f()                 (0x20U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_error_arrive_f()                   (0x21U)
#define gr_gpc0_tpc0_sm_tpc_esr_sm_sel_r()                         (0x0050460cU)
#define gr_gpc0_tpc0_sm_tpc_esr_sm_sel_sm0_error_v(r)       (((r) >> 0U) & 0x1U)
#define gr_gpc0_tpc0_sm_tpc_esr_sm_sel_sm1_error_v(r)       (((r) >> 1U) & 0x1U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_pc_r()                       (0x00504738U)
#define gr_gpc0_tpc0_sm0_hww_warp_esr_pc_hi_r()                    (0x0050473cU)
#define gr_gpcs_tpcs_pes_vsc_vpc_r()                               (0x0041be08U)
#define gr_gpcs_tpcs_pes_vsc_vpc_fast_mode_switch_true_f()                (0x4U)
#define gr_ppcs_wwdx_map_gpc_map_r(i)\
		(nvgpu_safe_add_u32(0x0041bf00U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_ppcs_wwdx_map_table_cfg_r()                             (0x0041bfd0U)
#define gr_ppcs_wwdx_map_table_cfg_row_offset_f(v)      ((U32(v) & 0xffU) << 0U)
#define gr_ppcs_wwdx_map_table_cfg_num_entries_f(v)     ((U32(v) & 0xffU) << 8U)
#define gr_ppcs_wwdx_map_table_cfg_normalized_num_entries_f(v)\
				((U32(v) & 0x1fU) << 16U)
#define gr_ppcs_wwdx_map_table_cfg_normalized_shift_value_f(v)\
				((U32(v) & 0x7U) << 21U)
#define gr_gpcs_ppcs_wwdx_sm_num_rcp_r()                           (0x0041bfd4U)
#define gr_gpcs_ppcs_wwdx_sm_num_rcp_conservative_f(v)\
				((U32(v) & 0xffffffU) << 0U)
#define gr_ppcs_wwdx_map_table_cfg_coeff_r(i)\
		(nvgpu_safe_add_u32(0x0041bfb0U, nvgpu_safe_mult_u32((i), 4U)))
#define gr_ppcs_wwdx_map_table_cfg_coeff__size_1_v()               (0x00000005U)
#define gr_ppcs_wwdx_map_table_cfg_coeff_0_mod_value_f(v)\
				((U32(v) & 0xffU) << 0U)
#define gr_ppcs_wwdx_map_table_cfg_coeff_1_mod_value_f(v)\
				((U32(v) & 0xffU) << 8U)
#define gr_ppcs_wwdx_map_table_cfg_coeff_2_mod_value_f(v)\
				((U32(v) & 0xffU) << 16U)
#define gr_ppcs_wwdx_map_table_cfg_coeff_3_mod_value_f(v)\
				((U32(v) & 0xffU) << 24U)
#define gr_bes_zrop_settings_r()                                   (0x00408850U)
#define gr_bes_zrop_settings_num_active_ltcs_f(v)        ((U32(v) & 0xfU) << 0U)
#define gr_bes_crop_debug3_r()                                     (0x00408908U)
#define gr_bes_crop_debug3_comp_vdc_4to2_disable_m()          (U32(0x1U) << 31U)
#define gr_bes_crop_debug3_blendopt_read_suppress_m()          (U32(0x1U) << 1U)
#define gr_bes_crop_debug3_blendopt_read_suppress_disabled_f()            (0x0U)
#define gr_bes_crop_debug3_blendopt_read_suppress_enabled_f()             (0x2U)
#define gr_bes_crop_debug3_blendopt_fill_override_m()          (U32(0x1U) << 2U)
#define gr_bes_crop_debug3_blendopt_fill_override_disabled_f()            (0x0U)
#define gr_bes_crop_debug3_blendopt_fill_override_enabled_f()             (0x4U)
#define gr_bes_crop_debug4_r()                                     (0x0040894cU)
#define gr_bes_crop_debug4_clamp_fp_blend_m()                 (U32(0x1U) << 18U)
#define gr_bes_crop_debug4_clamp_fp_blend_to_inf_f()                      (0x0U)
#define gr_bes_crop_debug4_clamp_fp_blend_to_maxval_f()               (0x40000U)
#define gr_bes_crop_settings_r()                                   (0x00408958U)
#define gr_bes_crop_settings_num_active_ltcs_f(v)        ((U32(v) & 0xfU) << 0U)
#define gr_zcull_bytes_per_aliquot_per_gpu_v()                     (0x00000020U)
#define gr_zcull_save_restore_header_bytes_per_gpc_v()             (0x00000020U)
#define gr_zcull_save_restore_subregion_header_bytes_per_gpc_v()   (0x000000c0U)
#define gr_zcull_subregion_qty_v()                                 (0x00000010U)
#define gr_gpcs_tpcs_tex_in_dbg_r()                                (0x00419a00U)
#define gr_gpcs_tpcs_tex_in_dbg_tsl1_rvch_invalidate_f(v)\
				((U32(v) & 0x1U) << 19U)
#define gr_gpcs_tpcs_tex_in_dbg_tsl1_rvch_invalidate_m()      (U32(0x1U) << 19U)
#define gr_gpcs_tpcs_sm_l1tag_ctrl_r()                             (0x00419bf0U)
#define gr_gpcs_tpcs_sm_l1tag_ctrl_cache_surface_ld_f(v) ((U32(v) & 0x1U) << 5U)
#define gr_gpcs_tpcs_sm_l1tag_ctrl_cache_surface_ld_m()        (U32(0x1U) << 5U)
#define gr_gpcs_tpcs_sm_l1tag_ctrl_cache_surface_st_f(v)\
				((U32(v) & 0x1U) << 10U)
#define gr_gpcs_tpcs_sm_l1tag_ctrl_cache_surface_st_m()       (U32(0x1U) << 10U)
#define gr_gpcs_tpcs_sm_l1tag_ctrl_always_cut_collector_m()   (U32(0x1U) << 28U)
#define gr_gpcs_tpcs_sm_l1tag_ctrl_always_cut_collector_disable_f()       (0x0U)
#define gr_gpcs_tpcs_sm_l1tag_ctrl_always_cut_collector_enable_f() (0x10000000U)
#define gr_fe_pwr_mode_r()                                         (0x00404170U)
#define gr_fe_pwr_mode_mode_auto_f()                                      (0x0U)
#define gr_fe_pwr_mode_mode_force_on_f()                                  (0x2U)
#define gr_fe_pwr_mode_req_v(r)                             (((r) >> 4U) & 0x1U)
#define gr_fe_pwr_mode_req_send_f()                                      (0x10U)
#define gr_fe_pwr_mode_req_done_v()                                (0x00000000U)
#define gr_gpcs_pri_mmu_ctrl_r()                                   (0x00418880U)
#define gr_gpcs_pri_mmu_ctrl_vm_pg_size_m()                    (U32(0x1U) << 0U)
#define gr_gpcs_pri_mmu_ctrl_use_pdb_big_page_size_m()        (U32(0x1U) << 11U)
#define gr_gpcs_pri_mmu_ctrl_comp_fault_m()                    (U32(0x1U) << 2U)
#define gr_gpcs_pri_mmu_ctrl_miss_gran_m()                     (U32(0x3U) << 3U)
#define gr_gpcs_pri_mmu_ctrl_cache_mode_m()                    (U32(0x3U) << 5U)
#define gr_gpcs_pri_mmu_ctrl_atomic_capability_mode_m()       (U32(0x3U) << 24U)
#define gr_gpcs_pri_mmu_ctrl_atomic_capability_sys_ncoh_mode_m()\
				(U32(0x1U) << 27U)
#define gr_gpcs_pri_mmu_pm_unit_mask_r()                           (0x00418890U)
#define gr_gpcs_pri_mmu_pm_req_mask_r()                            (0x00418894U)
#define gr_gpcs_pri_mmu_debug_ctrl_r()                             (0x004188b0U)
#define gr_gpcs_pri_mmu_debug_ctrl_debug_m()                  (U32(0x1U) << 16U)
#define gr_gpcs_pri_mmu_debug_ctrl_debug_enabled_f()                  (0x10000U)
#define gr_gpcs_pri_mmu_debug_ctrl_debug_disabled_f()                     (0x0U)
#define gr_gpcs_pri_mmu_debug_wr_r()                               (0x004188b4U)
#define gr_gpcs_pri_mmu_debug_rd_r()                               (0x004188b8U)
#define gr_gpcs_mmu_num_active_ltcs_r()                            (0x004188acU)
#define gr_gpcs_tpcs_sms_dbgr_control0_r()                         (0x00419e84U)
#define gr_fe_gfxp_wfi_timeout_r()                                 (0x004041c0U)
#define gr_fe_gfxp_wfi_timeout_count_f(v)         ((U32(v) & 0xffffffffU) << 0U)
#define gr_gpcs_tpcs_sm_texio_control_r()                          (0x00419bd8U)
#define gr_gpcs_tpcs_sm_texio_control_oor_addr_check_mode_m()  (U32(0x7U) << 8U)
#define gr_gpcs_tpcs_sm_texio_control_oor_addr_check_mode_arm_63_48_match_f()\
				(0x100U)
#define gr_gpcs_tpcs_sm_disp_ctrl_r()                              (0x00419ba4U)
#define gr_gpcs_tpcs_sm_disp_ctrl_re_suppress_m()             (U32(0x3U) << 11U)
#define gr_gpcs_tpcs_sm_disp_ctrl_re_suppress_disable_f()              (0x1000U)
#define gr_gpcs_tpcs_sm_disp_ctrl_compute_shader_quad_m()     (U32(0x1U) << 21U)
#define gr_gpcs_tpcs_sm_disp_ctrl_compute_shader_quad_enable_f()     (0x200000U)
#define gr_gpcs_tpcs_sm_disp_ctrl_compute_shader_quad_disable_f()         (0x0U)
#define gr_gpcs_tc_debug0_r()                                      (0x00418708U)
#define gr_gpcs_tc_debug0_limit_coalesce_buffer_size_f(v)\
				((U32(v) & 0x1ffU) << 0U)
#define gr_gpcs_tc_debug0_limit_coalesce_buffer_size_m()     (U32(0x1ffU) << 0U)
#define gr_debug_0_r()                                             (0x00400080U)
#define gr_debug_0_scg_force_slow_drain_tpc_m()               (U32(0x1U) << 11U)
#define gr_debug_0_scg_force_slow_drain_tpc_enabled_f()                 (0x800U)
#define gr_debug_2_r()                                             (0x00400088U)
#define gr_debug_2_gfxp_wfi_timeout_unit_m()                  (U32(0x1U) << 27U)
#define gr_debug_2_gfxp_wfi_timeout_unit_usec_f()                         (0x0U)
#define gr_debug_2_graphics_auto_go_idle_m()                  (U32(0x1U) << 17U)
#define gr_debug_2_graphics_auto_go_idle_disabled_f()                     (0x0U)
#define gr_debug_2_graphics_auto_go_idle_enabled_f()                  (0x20000U)
#define gr_debug_2_compute_auto_go_idle_m()                   (U32(0x1U) << 18U)
#define gr_debug_2_compute_auto_go_idle_disabled_f()                      (0x0U)
#define gr_debug_2_compute_auto_go_idle_enabled_f()                   (0x40000U)
#define gr_egpc0_etpc0_sm_dsm_perf_counter_control_sel0_r()        (0x00584200U)
#define gr_egpc0_etpc0_sm_dsm_perf_counter_control_sel1_r()        (0x00584204U)
#define gr_egpc0_etpc0_sm_dsm_perf_counter_control0_r()            (0x00584208U)
#define gr_egpc0_etpc0_sm_dsm_perf_counter_control1_r()            (0x00584210U)
#define gr_egpc0_etpc0_sm_dsm_perf_counter_control2_r()            (0x00584214U)
#define gr_egpc0_etpc0_sm_dsm_perf_counter_control3_r()            (0x00584218U)
#define gr_egpc0_etpc0_sm_dsm_perf_counter_control4_r()            (0x0058421cU)
#define gr_egpc0_etpc0_sm_dsm_perf_counter_control5_r()            (0x0058420cU)
#define gr_egpc0_etpc0_sm_dsm_perf_counter0_control_r()            (0x00584220U)
#define gr_egpc0_etpc0_sm_dsm_perf_counter1_control_r()            (0x00584224U)
#define gr_egpc0_etpc0_sm_dsm_perf_counter2_control_r()            (0x00584228U)
#define gr_egpc0_etpc0_sm_dsm_perf_counter3_control_r()            (0x0058422cU)
#define gr_egpc0_etpc0_sm_dsm_perf_counter4_control_r()            (0x00584230U)
#define gr_egpc0_etpc0_sm_dsm_perf_counter5_control_r()            (0x00584234U)
#define gr_egpc0_etpc0_sm_dsm_perf_counter6_control_r()            (0x00584238U)
#define gr_egpc0_etpc0_sm_dsm_perf_counter7_control_r()            (0x0058423cU)
#define gr_egpc0_etpc0_sm0_dsm_perf_counter4_r()                   (0x00584614U)
#define gr_egpc0_etpc0_sm0_dsm_perf_counter5_r()                   (0x00584618U)
#define gr_egpc0_etpc0_sm0_dsm_perf_counter6_r()                   (0x0058461cU)
#define gr_egpc0_etpc0_sm0_dsm_perf_counter7_r()                   (0x00584620U)
#define gr_gpc0_gpccs_falcon_ecc_status_r()                        (0x00502678U)
#define gr_gpc0_gpccs_falcon_ecc_status_corrected_err_imem_m() (U32(0x1U) << 0U)
#define gr_gpc0_gpccs_falcon_ecc_status_corrected_err_dmem_m() (U32(0x1U) << 1U)
#define gr_gpc0_gpccs_falcon_ecc_status_uncorrected_err_imem_m()\
				(U32(0x1U) << 4U)
#define gr_gpc0_gpccs_falcon_ecc_status_uncorrected_err_dmem_m()\
				(U32(0x1U) << 5U)
#define gr_gpc0_gpccs_falcon_ecc_status_uncorrected_err_total_counter_overflow_m()\
				(U32(0x1U) << 10U)
#define gr_gpc0_gpccs_falcon_ecc_status_corrected_err_total_counter_overflow_m()\
				(U32(0x1U) << 8U)
#define gr_gpc0_gpccs_falcon_ecc_status_reset_task_f()             (0x80000000U)
#define gr_gpc0_gpccs_falcon_ecc_address_r()                       (0x00502684U)
#define gr_gpc0_gpccs_falcon_ecc_address_row_address_v(r)\
				(((r) >> 0U) & 0xfffffU)
#define gr_gpc0_gpccs_falcon_ecc_corrected_err_count_r()           (0x0050267cU)
#define gr_gpc0_gpccs_falcon_ecc_corrected_err_count_total_v(r)\
				(((r) >> 0U) & 0xffffU)
#define gr_gpc0_gpccs_falcon_ecc_uncorrected_err_count_r()         (0x00502680U)
#define gr_gpc0_gpccs_falcon_ecc_uncorrected_err_count_total_v(r)\
				(((r) >> 0U) & 0xffffU)
#define gr_fecs_falcon_ecc_control_r()                             (0x0040968cU)
#define gr_fecs_falcon_ecc_control_inject_corrected_err_f(v)\
				((U32(v) & 0x1U) << 0U)
#define gr_fecs_falcon_ecc_control_inject_uncorrected_err_f(v)\
				((U32(v) & 0x1U) << 1U)
#define gr_fecs_falcon_ecc_status_r()                              (0x00409678U)
#define gr_fecs_falcon_ecc_status_corrected_err_imem_m()       (U32(0x1U) << 0U)
#define gr_fecs_falcon_ecc_status_corrected_err_dmem_m()       (U32(0x1U) << 1U)
#define gr_fecs_falcon_ecc_status_uncorrected_err_imem_m()     (U32(0x1U) << 4U)
#define gr_fecs_falcon_ecc_status_uncorrected_err_dmem_m()     (U32(0x1U) << 5U)
#define gr_fecs_falcon_ecc_status_uncorrected_err_total_counter_overflow_m()\
				(U32(0x1U) << 10U)
#define gr_fecs_falcon_ecc_status_corrected_err_total_counter_overflow_m()\
				(U32(0x1U) << 8U)
#define gr_fecs_falcon_ecc_status_reset_task_f()                   (0x80000000U)
#define gr_fecs_falcon_ecc_address_r()                             (0x00409684U)
#define gr_fecs_falcon_ecc_address_row_address_v(r)     (((r) >> 0U) & 0xfffffU)
#define gr_fecs_falcon_ecc_corrected_err_count_r()                 (0x0040967cU)
#define gr_fecs_falcon_ecc_corrected_err_count_total_v(r)\
				(((r) >> 0U) & 0xffffU)
#define gr_fecs_falcon_ecc_uncorrected_err_count_r()               (0x00409680U)
#define gr_fecs_falcon_ecc_uncorrected_err_count_total_v(r)\
				(((r) >> 0U) & 0xffffU)
#define gr_pri_gpc0_gcc_l15_ecc_status_r()                         (0x00501048U)
#define gr_pri_gpc0_gcc_l15_ecc_status_corrected_err_bank0_m() (U32(0x1U) << 0U)
#define gr_pri_gpc0_gcc_l15_ecc_status_corrected_err_bank1_m() (U32(0x1U) << 1U)
#define gr_pri_gpc0_gcc_l15_ecc_status_uncorrected_err_bank0_m()\
				(U32(0x1U) << 4U)
#define gr_pri_gpc0_gcc_l15_ecc_status_uncorrected_err_bank1_m()\
				(U32(0x1U) << 5U)
#define gr_pri_gpc0_gcc_l15_ecc_status_corrected_err_total_counter_overflow_v(r)\
				(((r) >> 8U) & 0x1U)
#define gr_pri_gpc0_gcc_l15_ecc_status_uncorrected_err_total_counter_overflow_v(r)\
				(((r) >> 10U) & 0x1U)
#define gr_pri_gpc0_gcc_l15_ecc_status_reset_task_f()              (0x40000000U)
#define gr_pri_gpc0_gcc_l15_ecc_corrected_err_count_r()            (0x0050104cU)
#define gr_pri_gpc0_gcc_l15_ecc_corrected_err_count_total_v(r)\
				(((r) >> 0U) & 0xffffU)
#define gr_pri_gpc0_gcc_l15_ecc_uncorrected_err_count_r()          (0x00501054U)
#define gr_pri_gpc0_gcc_l15_ecc_uncorrected_err_count_total_s()            (16U)
#define gr_pri_gpc0_gcc_l15_ecc_uncorrected_err_count_total_v(r)\
				(((r) >> 0U) & 0xffffU)
#define gr_gpc0_mmu0_l1tlb_ecc_control_r()                         (0x00501410U)
#define gr_gpc0_mmu0_l1tlb_ecc_control_inject_uncorrected_err_f(v)\
				((U32(v) & 0x1U) << 5U)
#define gr_gpc0_mmu0_gpcmmu_global_esr_r()                         (0x00501424U)
#define gr_gpc0_mmu0_gpcmmu_global_esr_ecc_corrected_m()       (U32(0x1U) << 0U)
#define gr_gpc0_mmu0_gpcmmu_global_esr_ecc_uncorrected_m()     (U32(0x1U) << 1U)
#define gr_gpc0_mmu0_l1tlb_ecc_status_r()                          (0x00501414U)
#define gr_gpc0_mmu0_l1tlb_ecc_status_corrected_err_l1tlb_sa_data_m()\
				(U32(0x1U) << 0U)
#define gr_gpc0_mmu0_l1tlb_ecc_status_corrected_err_l1tlb_fa_data_m()\
				(U32(0x1U) << 2U)
#define gr_gpc0_mmu0_l1tlb_ecc_status_uncorrected_err_l1tlb_sa_data_m()\
				(U32(0x1U) << 1U)
#define gr_gpc0_mmu0_l1tlb_ecc_status_uncorrected_err_l1tlb_fa_data_m()\
				(U32(0x1U) << 3U)
#define gr_gpc0_mmu0_l1tlb_ecc_status_uncorrected_err_total_counter_overflow_m()\
				(U32(0x1U) << 18U)
#define gr_gpc0_mmu0_l1tlb_ecc_status_corrected_err_total_counter_overflow_m()\
				(U32(0x1U) << 16U)
#define gr_gpc0_mmu0_l1tlb_ecc_status_reset_task_f()               (0x40000000U)
#define gr_gpc0_mmu0_l1tlb_ecc_address_r()                         (0x00501420U)
#define gr_gpc0_mmu0_l1tlb_ecc_corrected_err_count_r()             (0x00501418U)
#define gr_gpc0_mmu0_l1tlb_ecc_corrected_err_count_total_s()               (16U)
#define gr_gpc0_mmu0_l1tlb_ecc_corrected_err_count_total_v(r)\
				(((r) >> 0U) & 0xffffU)
#define gr_gpc0_mmu0_l1tlb_ecc_uncorrected_err_count_r()           (0x0050141cU)
#define gr_gpc0_mmu0_l1tlb_ecc_uncorrected_err_count_total_s()             (16U)
#define gr_gpc0_mmu0_l1tlb_ecc_uncorrected_err_count_total_v(r)\
				(((r) >> 0U) & 0xffffU)
#define gr_gpcs_gpccs_engine_reset_ctl_r()                         (0x0041a610U)
#define gr_gpcs_gpccs_engine_reset_ctl_gpc_engine_reset_enabled_f()       (0x0U)
#define gr_gpcs_gpccs_engine_reset_ctl_gpc_engine_reset_disabled_f()      (0x1U)
#define gr_gpc0_gpccs_engine_reset_ctl_r()                         (0x00502610U)
#define gr_gpc0_gpccs_engine_reset_ctl_gpc_engine_reset_v(r)\
				(((r) >> 0U) & 0x1U)
#define gr_gpc0_gpccs_engine_reset_ctl_gpc_engine_reset_disabled_v()\
				(0x00000001U)
#define gr_gpcs_tpcs_sm_l1tag_ctrl_r()                             (0x00419bf0U)
#define gr_gpcs_tpcs_sm_l1tag_ctrl_surface_cut_collector_enable_f()\
				(0x20000000U)
#define gr_gpc0_tpc0_sm_l1tag_ctrl_r()                             (0x005043f0U)
#define gr_gpcs_pri_tpcs_sm_sch_macro_sched_r()                    (0x00419b48U)
#define gr_gpcs_pri_tpcs_sm_sch_macro_sched_exit_wait_for_errbar_m()\
				(U32(0x1U) << 20U)
#define gr_gpcs_pri_tpcs_sm_sch_macro_sched_exit_wait_for_errbar_enabled_f()\
				(0x100000U)
#define gr_gpcs_pri_tpcs_sm_sch_macro_sched_exit_wait_for_errbar_disabled_f()\
				(0x0U)
#define gr_graphics_class_v()                                      (0x0000c697U)
#define gr_graphics_method_set_shader_exceptions_v()               (0x00001528U)
#define gr_graphics_method_set_shader_exceptions_enable_false_v()  (0x00000000U)
#define gr_graphics_method_set_go_idle_timeout_v()                 (0x0000022cU)
#define gr_graphics_method_set_circular_buffer_size_v()            (0x00001280U)
#define gr_graphics_method_set_alpha_circular_buffer_size_v()      (0x000002dcU)
#define gr_graphics_method_set_cb_base_v()                         (0x00001014U)
#define gr_graphics_method_set_bes_crop_debug4_v()                 (0x000010b0U)
#define gr_graphics_method_set_tex_in_dbg_v()                      (0x000010bcU)
#define gr_graphics_method_set_skedcheck_v()                       (0x000010c0U)
#define gr_compute_class_v()                                       (0x0000c6c0U)
#define gr_compute_method_set_shader_exceptions_v()                (0x00001528U)
#define gr_compute_method_set_cb_base_v()                          (0x00000220U)
#define gr_compute_method_set_bes_crop_debug4_v()                  (0x0000022cU)
#define gr_compute_method_set_tex_in_dbg_v()                       (0x00000238U)
#define gr_compute_method_set_skedcheck_v()                        (0x0000023cU)
#endif
